#
# Syntax:
# ------
# Resource, <ID>, <Category> [,<Name>]
#     uint32,   	<Name>   [,<Min>,       <Max>,           <Default>,   <Sep>]
#     string,   	<Name>                                 [,<Default>,   <Sep>]
#     enum,       <Name>,  <EnumList/EnumTable ID>       [,<Default>,   <Sep>]
#     complex,  	<Name>   [,<MinOccurs>, <MaxOccurs>,     <Default>,   <Sep>]		
#        // List of contained simple types. No containment of complex types.
#     }
# }
#
# EnumList, <ID>
#     <Value1>[, <Label1>]
#     <Value1>[, <Label1>]
#        :
#     <ValueN>[, <LabelN>]
# }
#

#
# Enum Lists
#
EnumList, IDEL_YESNO
   No, No
   Yes, Yes
}
EnumList, IDEL_LABEL_YESNO
   0, No
   1, Yes
}
EnumList, IDEL_FORMFACTOR
   1, Candy Bar
   2, Clamshell
   3, Slider
   99, Other
}
EnumList, IDEL_PROCESSORCORE
   1, ARM7
   2, ARM9,
   99, Other
}
EnumList, IDEL_FILESYSTEM
   1, EFS1
   2, EFS2
   99, Other
}
EnumList, IDEL_FLASH
   1, NAND
   2, NOR
   99, Other
}
EnumList, IDEL_NUM_MMC_SUPPORT
   1, 1
   2, 2
   99, Not Supported
}

#<!--=================================================================
#        Device Model Info
#=================================================================-->
Resource, IDS_DD_DEV_MFC, Device Model Info
   string, Manufacturer, , |
   HELP
      Enter the device manufacturer's name (your company name).
   }
}
Resource, IDS_DD_DEV_MODEL, Device Model Info
   string, Model
   HELP
      Enter the model number of the device.  This should be the commercial
      name/number, not an internal project name or code name.
   }
}
Resource, IDS_DD_DEV_ID, Device Model Info
   uint32, Platform Id
   HELP
      Contact Qualcomm Internet Services (QIS) for this value.
   }
}
Resource, IDS_DD_DEV_BREW_VER, Device Model Info
   string, BREW Version
   HELP
      Version of BREW on the device including all Patches and 
			Feature Packages eg. 3.1.3U01FP02. This information is present in 
			the release notes of the BREW Porting Kit.
   }
}
Resource, IDS_DD_DEV_CHIPSET, Device Model Info
   string, Chipset
   HELP
      Enter the chipset used by this device, for example 6100.      
   }
}
Resource, IDS_DD_DEV_BUILD_VER, Device Model Info
   string, Build Version
   HELP
      Enter the OEM Handset SW version.  Also, document how this information
      can be accessed through the handset UI in the Comment field.
   }
}
Resource, IDS_DD_DEV_FORMFACTOR, Device Model Info
   enum, Form Factor, IDEL_FORMFACTOR
   HELP
      Select device form factor (e.g. candy bar, clamshell, sider, etc.  If none of the
      listed form factors apply, select "Other" and describe the form factor in the
      Comment field.
   }
}
Resource, IDS_DD_DEV_DEVPACK_VER, Device Model Info
   string, Device Pack Version
   HELP
      Enter the Device Pack version.  This is a version number assigned
      by the OEM to this Device Pack.  It is expected that this version
      number will change each time an OEM submits a changed version of
      this Device Pack.

      Filename convention - The following convention will be used for the file version scheme; for both DDF and Device Pack File.

      ___.dso/dst/dpk/sch
      where .dso/dst/dpk/sch refer to Device Pack related filenames.

      The following rules apply to the naming convention of the filename:
      1.  Excluded characters - periods (.) and underscores (_) are not allowed within the OEM Name, Device Model, and Carrier Name fields.
      2.  x.y = BREW Version
      3.  z = DDF or DPF version number
      4.  a = OEM version number

   }
}
Resource, IDS_DD_DEV_PEK_VER, Device Model Info
   string, PEK Version
   HELP
      Enter the PEK version used to test this device including all Patches
			and Feature Packages eg. 3.1.3U01FP02
   }
}
Resource, IDS_DD_DEV_APPMGR_VER, Device Model Info
   string, BREW App Manager version
   HELP
      Enter the version of AppManager on the device including all Patches
			and Feature Packages eg. 2.1.2U01FP02

   }
}
Resource, IDS_DD_SCHEMA_VER, Device Pack Schema Info
   string, Device Pack Schema Version
   HELP
      Enter the Device Pack Schema version in 3 digits. The first two digits specify the
      major BREW release and the last digit the schema version. For example, 3.1.0
   }
}
Resource, IDS_DD_DEV_PROCESSOR_CORE, Device Model Info
   enum, Processor Core, IDEL_PROCESSORCORE
   HELP
      Select device Processor Core, e.g. ARM7, ARM9, etc. If none of the listed processor
      cores apply, select "Other" and describe the processor core in the Comment field.
   }
}
Resource, IDS_DD_DEV_FILE_SYSTEM, Device Model Info
   enum, File System, IDEL_FILESYSTEM
   HELP
      Select device File System, e.g. EFS1, EFS2, etc. If none of the listed file systems
      apply, select "Other" and describe the file system in the Comment field.
   }
}
Resource, IDS_DD_DEV_FLASH, Device Model Info
   enum, Flash Type, IDEL_FLASH
   HELP
      Select device Flash type, e.g. NAND, NOR, etc. If none of the listed flash types
      apply, select "Other" and describe the files system in the Comment field.
   }
} 
Resource, IDS_DD_SERIAL_BLOCKING_SUPPORT, Device Model Info
   enum, Serial Port Blocking, IDEL_LABEL_YESNO
	 HELP
	    Does the device support blocking of the serial port?
   }
}
Resource, IDS_DD_PORT_NAMES, Device Model Info
   string, Serial Port Names, , |
	 HELP
	    If serial ports are supported through BREW, enter the port names here 
			e.g. PORT1,PORT2,USB1,USB2. Otherwise leave black
   }
}
Resource, IDS_DD_DEV_BREW_UPDATE_VER, Device Model Info
   string, Patch Name, , |
   HELP
      Enter a comma separated list of patches applied.  For
      example: P1,P2,P3,P4,P5.
      If no patch is applied to device enter: none
   }
} 
Resource, IDS_DD_OPENGL_ES, Device Model Info
   enum, OpenGL ES, IDEL_LABEL_YESNO
	 HELP
	    Does the device support OpenGL ES?
   }
}
Resource, IDS_DD_RUIM_SUPPORTED, Device Model Info
   enum, RUIM Support, IDEL_LABEL_YESNO
	 HELP
	    Does the device support RUIM?
   }
}
Resource, IDS_DD_SMS_TELESERVICE_SUPPORT, Device Model Info
   enum, SMS Teleservice, IDEL_LABEL_YESNO
	 HELP
	    Does the device support SMS Teleservice?
	 }
}
Resource, IDS_DD_DIAG_EXT_SUPPORT, Device Model Info
   enum, Diag Extension, IDEL_LABEL_YESNO
	 HELP
	    Does the device support the Diag Extension?
   }
}
Resource, IDS_DD_LANG_OFFSET, Device Model Info
   uint32, Language Offset
	 HELP
	    Enter the offset between the Language code of the Language the
			phone is currently in and the Language code of the next language
			device supports.If the device does not support any othe
			languages enter 0
	 }
}
Resource, IDS_DD_BTIL_SPT, Device Model Info
   enum, BTIL Support, IDEL_LABEL_YESNO
   HELP
      Does the device support the BTIL (BREW Tools Interface Layer) to communicate to external devices?
   }
}
Resource, IDS_DD_BTIL_VER, Device Model Info
   string, BTIL Version
   HELP
      Enter the version of BTIL used if the device supports BTIL. 
   }
}
Resource, IDS_TB_DEVICE_CATEGORIZATION_PATH, Device Model Info
   string, Device Categorization Path
	 HELP
	    Enter the path representing the desired device class hierarchy for the Device.
	 }
}
Resource, IDS_DD_LNP_CONF, Device Model Info
   enum, LNP Configuration, IDEL_LABEL_YESNO
       HELP
          Is the device currently configured for Local Number Portability? So that the MDN of the device does not equal the MIN of the device.
       }
}
Resource, IDS_DD_IMODEL_SUPPORT, Device Model Info
   enum, IModel Support, IDEL_LABEL_YESNO
       HELP
          Does the device have support for the IModel notification interface with IConfig.
       }
}

#<!--=================================================================
#        Network/Socket Specification
#=================================================================-->
Resource, IDS_DD_NET_RF_SUPP, Network/Socket Specification
   string, Radio Frequency, , |
   HELP
      Enter a comma separated list of frequency bands supported.  For 
      example: 800 MHz, 1800 MHz, 1900 MHz.
   }
}
Resource, IDS_DD_NET_STD_SUPP, Network/Socket Specification
   string, Wireless Standard, , |
   HELP
      Enter a comma separated list of standards supported.  For
      example: IS-95A, IS-95B, 1x.
   }
}
Resource, IDS_DD_DATA_MAX_TCP, Network/Socket Specification
   uint32, Max TCP Sockets
   HELP
      Enter the number of simultaneous TCP sockets supported on the device.
   }
}
Resource, IDS_DD_DATA_MAX_UDP, Network/Socket Specification
   uint32, Max UDP Sockets
   HELP
      Enter the number of simultaneous UDP sockets supported on the device.
   }
}
Resource, IDS_DD_DATA_LINGER, Network/Socket Specification
   uint32, Linger timer duration (msecs)
   HELP
      Enter the duration of the linger timer on the handset in msecs.
   }
}
Resource, IDS_DD_DATA_DORMANCY, Network/Socket Specification
   enum, Dormancy Support, IDEL_LABEL_YESNO
   HELP
      Does the handset support network initiated dormancy?
   }
}
Resource, IDS_DD_AIRPLANE_MODE, Network/Socket Specification
   enum, Airplane Mode Support, IDEL_LABEL_YESNO
   HELP
      Does the device support airplane mode (the mobile device's RF both
      Rx and Tx are turned Off)?
   }
}
Resource, IDS_DD_HDR_MODE, Network/Socket Specification
   enum, 1xEVDO Support, IDEL_LABEL_YESNO
   HELP
      Does the device support 1xEV-DO (HDR)?
   }
}
Resource, IDS_DD_UMTS_MODE, Network/Socket Specification
   enum, UMTS Support, IDEL_LABEL_YESNO
   HELP
      Does the device support UMTS (WCDMA)?
   }
}
Resource, IDS_DD_QOS_SUPPORT, Network/Socket Specification
   enum, QoS Support, IDEL_LABEL_YESNO
   HELP
      Does the handset support Quality of Service?
   }
}
Resource, IDS_DD_BCMCS, Network/Socket Specification
   enum, BCMCS Support, IDEL_LABEL_YESNO
   HELP
      Does the handset support EVDO Broadcast Multicast Service?
   }
}


#<!--=================================================================
#        Hardware Specification
#=================================================================-->
#<!--_______________________________________
#                Memory
#_______________________________________-->
Resource, IDS_DD_HW_RAM_SIZE, Memory
   uint32, RAM Size (bytes)
   HELP
      Enter brew heap size in bytes.
   }
}
Resource, IDS_DD_HW_STACK_SIZE, Memory
   uint32, Stack Size (bytes)
   HELP
      Enter stack available to brew in bytes.  Generally this is the stack size
      of the task that BREW runs in.
   }
}
Resource, IDS_DD_HW_EFS_SIZE, Memory
   uint32, EFS Size (bytes)
   HELP
      Enter the size of the embedded file system that can be used for BREW
      applications in bytes.
   }
}
Resource, IDS_DD_HW_EFS_MIN_PATH, Memory
   uint32, File Name Length
   HELP
      How many characters can included in a BREW file name from the ".../brew/oat/"
      directory.
   }
}
Resource, IDS_DD_HW_EFS_MIN_FILES, Memory
   uint32, Number of BREW Files
   HELP
      Enter the maximum number of files that may be created in the brew
      directory tree.
      
      Generally this should only be limited by EFS limitations.  If the number
      of files is limited only by the EFS, enter 0, and say "No Limit" in
      the Comment field.
   }
}
Resource, IDS_DD_HW_EFS_MIN_FILESIZE, Memory
   uint32, File Size (bytes)
   HELP
      If there is any limitation on the size of an individual BREW file,
      specify that size in bytes.  Generally this should be as large as
      the size of the EFS.
      
      If there is no limitation, specify O and enter "No Limit" in the OEM
      Comment field.
   }
}
Resource, IDS_DD_HW_MMC_SUPPORT, Memory
   enum, Removable  Media Card Support, IDEL_LABEL_YESNO
   HELP
      Does the handset have a removable media card available to BREW?  Typically,
      a removable media card would be available through the file system as
      fs:/card0/... (BREW 3.0 and later only).  Document any differences in the
      Comment section.
   }
}
Resource, IDS_DD_HW_NUM_MMC_SUPPORT, Memory
   enum, Number Media Card Slot, IDEL_NUM_MMC_SUPPORT
   HELP
      How many removeable media card slots does the the device have available to
			BREW? 
			Select Not Supported if the device does not have any media card slots
			available to BREW, otherwise select the number available.
   }
}
Resource, IDS_DD_HW_MMC1_SIZE, Memory
   uint32, Media Card Size Slot 1 (bytes)
   HELP
      What is the size of the media card inserted in slot 1 of the device?
			If the device does not have a media card slot 1 put 0.
   }
}
Resource, IDS_DD_HW_MMC1_SIZE_VARIANCE, Memory
   uint32, Media Card Size Measurement Variance Slot 1 (bytes)
   HELP
      What is the allowable variance of the measurement of the size of the media card inserted in slot 1 of the device?
			If the device does not have a media card slot 1 put 0.
   }
}
Resource, IDS_DD_HW_MMC2_SIZE, Memory
   uint32, Media Card Size Slot 2 (bytes)
   HELP
      What is the size of the media card inserted in slot 2 of the device?
			If the device does not have a media card slot 2 put 0.
   }
}
Resource, IDS_DD_HW_MMC2_SIZE_VARIANCE, Memory
   uint32, Media Card Size Measurement Variance Slot 2 (bytes)
   HELP
      What is the allowable variance of the measurement of the size of the media card inserted in slot 2 of the device?
			If the device does not have a media card slot 1 put 0.
   }
}
Resource, IDS_DD_MMC_MODELNUM_SERIALNUM_SUPPORTED, Memory
   enum, Media Card Model and Serial Number Support, IDEL_YESNO
   HELP
      Does the handset provide media card model and serial number to BREW?
      If yes, set the value to "Yes" else "No".   
   }
}
Resource, IDS_DD_MMC_MODELNUM_SERIALNUM_INFO, Memory
   string, Media Card info, , |
   HELP
      If model and serial number for media card is supported through BREW,
      enter the comma seperated model and serial number for each card. 
      e.g. 1,SMD-1,200,2,SMD-1,201  - means for card 1 model number is SMD-1
      and serial number is 200, for card 2 model number is SMD-1 and serial
      number is 201. card 1 is treated as fs:/card0 which is the only card
      which is tested at present.
   }
}
#<!--___________________________________________________________________
#        Displays
#__________________________________________________________________-->
EnumList, IDEL_DISPLAY_CLSID
16852948, display1
16852949, display2
16852950, display3
16852951, display4   
}
#<!--___________________________________________________________________
#        Display 1
#__________________________________________________________________-->
Resource, IDS_DD_LCD_DIM_X, Display 1
   uint32, Size X
   HELP
      Enter the width of the display in pixels.  This should be
      only the pixels available to BREW.  For example, if your display was
      100 pixels wide, but 10 pixels were used for status at the side of
      the display and are not available to BREW, you would enter 90.
   }
}
Resource, IDS_DD_LCD_DIM_Y, Display 1
   uint32, Size Y
   HELP
      Enter the height of the display in pixels.  This should be
      only the pixels available to BREW.  For example, if your display was
      100 pixels high, but 10 pixels were used for status at the top of
      the display and are not available to BREW, you would enter 90.
   }
}
Resource, IDS_DD_LCD_DEPTH, Display 1
   uint32, BREW Default Color Depth (bits)
   HELP
      Enter the display's default color depth (in bits) in BREW.
      This is the mode that the device bitmap is in when an app start, unless specified
			otherwise in the app's MIF.

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.
   }
}
Resource, IDS_DD_LCD_DEPTH_HW, Display 1
   uint32, HW Color Depth (bits)
   HELP
      Enter the display's maximum color depth (in bits) supported by the device.
      hardware and native user interface.  This value is typically the same
      as BREW Color Depth, but may be different on some devices.  This value
      may be used by developers to create native UI wallpaper, etc.

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.
   }
}
Resource, IDS_DD_LCD_REF_RATE, Display 1
   uint32, Refresh Rate (frames/sec)
   HELP
      Enter the hardware refresh rate of the display in frames/sec.
   }
}
Resource, IDS_DD_LCD_TYPE, Display 1
   string, Display Type
   HELP
      Enter the display's LCD type.  For example: TFT, STN, etc.
   }
}
Resource, IDS_DD_LCD_PITCH, Display 1
   string, Pixel Pitch, , |
   HELP
      Enter the display's pixel block size and spacing between pixels
      in mm in the form SizeX x SizeY, SpaceX x SpaceY.  For example, 0.2mm x 0.2mm,
      0.01mm x 0.01mm.
   }
}
Resource, IDS_DD_LCD_SUPPORTED_DEPTHS, Display 1
   string, BREW Supported Color Depths (bits), , |
	 HELP
	    This is a comma separated list of all the color depth modes supported by the 
			display in BREW.
      For example, for a display that can be in either 16- or 18-bit mode, 
			enter "16, 18". 
	 }
}

#<!--___________________________________________________
#        Display 2
#_______________________________________________________-->
Resource, IDS_DD_LCD2_DIM_X, Display 2
   uint32, Size X
   HELP
      Enter the width of the display in pixels.  This should be only the
      pixels available to BREW.  For example, if your display was
      100 pixels wide, but 10 pixels were used for status at the side of
      the display and are not available to BREW, you would enter 90.
      
      If there is no display, enter 0.
   }  
}
Resource, IDS_DD_LCD2_DIM_Y, Display 2
   uint32, Size Y
   HELP
      Enter the height of the display in pixels.  This should be only the
      pixels available to BREW.  For example, if your display was 20 pixels
      high, but 5 pixels were used for status at the top of the display and
      are not available to brew, you would enter 15.

      If there is no display, enter 0.
   }
}
Resource, IDS_DD_LCD2_DEPTH, Display 2
   uint32, BREW Default Color Depth
   HELP
      Enter the display's maximum color depth (in bits) supported in
      BREW. This is the mode that the device bitmap is in when an app starts, unless specified
			otherwise in the app's MIF.
			

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.

      If there is no display, enter 0.
   }
}
Resource, IDS_DD_LCD2_DEPTH_HW, Display 2
   uint32, HW Color Depth (bits)
   HELP
      Enter the display's maximum color depth (in bits) supported
      by the device hardware and native user interface.  This value is 
      typically the same as BREW Color Depth, but may be different on some
      devices.  This value may be used by developers to create native UI 
      wallpaper, etc.

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.
   }
}
Resource, IDS_DD_LCD2_REF_RATE, Display 2
   uint32, Refresh Rate (frames/sec)
   HELP
      Enter the hardware refresh rate of the display in frames/sec.

      If there is no secondary display, enter 0.
   }
}
Resource, IDS_DD_LCD2_TYPE, Display 2
   string, Type
   HELP
      Enter the display's LCD type.  For example: TFT, STN, etc.

      If there is no secondary display, leave this entry blank.
   }
}
Resource, IDS_DD_LCD2_PITCH, Display 2
   string, Pixel Pitch, , |
   HELP
      Enter the display's pixel block size and spacing between pixels
      in mm in the form SizeX x SizeY, SpaceX x SpaceY.  For example, 0.2mm x 0.2mm,
      0.01mm x 0.01mm.

      If there is no secondary display, leave this entry blank.
   }
}
Resource, IDS_DD_LCD2_SUPPORTED_DEPTHS, Display 2
   string, BREW Supported Color Depths (bits), , |
	 HELP
	    This is a comma separated list of all the color depth modes supported by the 
			display in BREW.
      For example, for a display that can be in either 16- or 18-bit mode, 
			enter "16, 18". 
	 }
}

#<!--___________________________________________________
#        Display 3
#_______________________________________________________-->
Resource, IDS_DD_LCD3_DIM_X, Display 3
   uint32, Size X
   HELP
      Enter the width of the display in pixels.  This should be only the
      pixels available to BREW.  For example, if your display was
      100 pixels wide, but 10 pixels were used for status at the side of
      the display and are not available to BREW, you would enter 90.
      
      If there is no display, enter 0.
   }  
}
Resource, IDS_DD_LCD3_DIM_Y, Display 3
   uint32, Size Y
   HELP
      Enter the height of the display in pixels.  This should be only the
      pixels available to BREW.  For example, if your display was 20 pixels
      high, but 5 pixels were used for status at the top of the display and
      are not available to brew, you would enter 15.

      If there is no display, enter 0.
   }
}
Resource, IDS_DD_LCD3_DEPTH, Display 3
   uint32, BREW Default Color Depth
   HELP
      Enter the display's maximum color depth (in bits) supported in
      BREW. This is the mode that the device bitmap is in when an app starts, unless specified
			otherwise in the app's MIF.
			

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.

      If there is no display, enter 0.
   }
}
Resource, IDS_DD_LCD3_DEPTH_HW, Display 3
   uint32, HW Color Depth (bits)
   HELP
      Enter the display's maximum color depth (in bits) supported
      by the device hardware and native user interface.  This value is 
      typically the same as BREW Color Depth, but may be different on some
      devices.  This value may be used by developers to create native UI 
      wallpaper, etc.

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.
   }
}
Resource, IDS_DD_LCD3_REF_RATE, Display 3
   uint32, Refresh Rate (frames/sec)
   HELP
      Enter the hardware refresh rate of the display in frames/sec.

      If there is no secondary display, enter 0.
   }
}
Resource, IDS_DD_LCD3_TYPE, Display 3
   string, Type
   HELP
      Enter the display's LCD type.  For example: TFT, STN, etc.

      If there is no secondary display, leave this entry blank.
   }
}
Resource, IDS_DD_LCD3_PITCH, Display 3
   string, Pixel Pitch, , |
   HELP
      Enter the display's pixel block size and spacing between pixels
      in mm in the form SizeX x SizeY, SpaceX x SpaceY.  For example, 0.2mm x 0.2mm,
      0.01mm x 0.01mm.

      If there is no secondary display, leave this entry blank.
   }
}
Resource, IDS_DD_LCD3_SUPPORTED_DEPTHS, Display 3
   string, BREW Supported Color Depths (bits), , |
	 HELP
	    This is a comma separated list of all the color depth modes supported by the 
			display in BREW.
      For example, for a display that can be in either 16- or 18-bit mode, 
			enter "16, 18". 
	 }
}

#<!--___________________________________________________
#        Display 4
#_______________________________________________________-->
Resource, IDS_DD_LCD4_DIM_X, Display 4
   uint32, Size X
   HELP
      Enter the width of the display in pixels.  This should be only the
      pixels available to BREW.  For example, if your display was
      100 pixels wide, but 10 pixels were used for status at the side of
      the display and are not available to BREW, you would enter 90.
      
      If there is no display, enter 0.
   }  
}
Resource, IDS_DD_LCD4_DIM_Y, Display 4
   uint32, Size Y
   HELP
      Enter the height of the display in pixels.  This should be only the
      pixels available to BREW.  For example, if your display was 20 pixels
      high, but 5 pixels were used for status at the top of the display and
      are not available to brew, you would enter 15.

      If there is no display, enter 0.
   }
}
Resource, IDS_DD_LCD4_DEPTH, Display 4
   uint32, BREW Default Color Depth
   HELP
      Enter the display's maximum color depth (in bits) supported in
      BREW. This is the mode that the device bitmap is in when an app starts, unless specified
			otherwise in the app's MIF.
			

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.

      If there is no display, enter 0.
   }
}
Resource, IDS_DD_LCD4_DEPTH_HW, Display 4
   uint32, HW Color Depth (bits)
   HELP
      Enter the display's maximum color depth (in bits) supported
      by the device hardware and native user interface.  This value is 
      typically the same as BREW Color Depth, but may be different on some
      devices.  This value may be used by developers to create native UI 
      wallpaper, etc.

      For example, enter 16 for a device that has a bit depth of 16 and supports
      65536 colors.
   }
}
Resource, IDS_DD_LCD4_REF_RATE, Display 4
   uint32, Refresh Rate (frames/sec)
   HELP
      Enter the hardware refresh rate of the display in frames/sec.

      If there is no secondary display, enter 0.
   }
}
Resource, IDS_DD_LCD4_TYPE, Display 4
   string, Type
   HELP
      Enter the display's LCD type.  For example: TFT, STN, etc.

      If there is no secondary display, leave this entry blank.
   }
}
Resource, IDS_DD_LCD4_PITCH, Display 4
   string, Pixel Pitch, , |
   HELP
      Enter the display's pixel block size and spacing between pixels
      in mm in the form SizeX x SizeY, SpaceX x SpaceY.  For example, 0.2mm x 0.2mm,
      0.01mm x 0.01mm.

      If there is no secondary display, leave this entry blank.
   }
}
Resource, IDS_DD_LCD4_SUPPORTED_DEPTHS, Display 4
   string, BREW Supported Color Depths (bits), , |
	 HELP
	    This is a comma separated list of all the color depth modes supported by the 
			display in BREW.
      For example, for a display that can be in either 16- or 18-bit mode, 
			enter "16, 18". 
	 }
}

#<!--_______________________________________
#        Backlight
#_______________________________________-->
Resource, IDS_DD_BACKLIGHT_MAX_BRIGHT_LEVEL, Backlight
   uint32, Maximum Brightness Level
	 HELP
	    What is the maximum brightness level of the backlight on the device?
   }
}
Resource, IDS_DD_BACKLIGHT_MIN_BRIGHT_LEVEL, Backlight
   uint32, Minimum Brightness Level
	 HELP
	    What is the minimum brightness level of the backlight on the device?
   }
}
Resource, IDS_DD_BACKLIGHT_DEF_BRIGHT_LEVEL, Backlight
   uint32, Default Brightness Level
	 HELP
	    What is the default brightness level of the backlight on the device?
   }
}
Resource, IDS_DD_BACKLIGHT_COLOR, Backlight
   uint32, Backlight Color
	 HELP
	    What is the RGB value of the backlight on the device?
   }
}


#<!--_______________________________________
#                Keypad
#_______________________________________-->
EnumList, IDEL_KEYPAD
   None, None
   AVK_SELECT
   AVK_LEFT
   AVK_RIGHT
   AVK_UP
   AVK_DOWN
   AVK_FUNCTION1
   AVK_FUNCTION2
   AVK_SOFT1
   AVK_SOFT2
   AVK_MENU
   AVK_MESSAGE
   AVK_SEND
   Other, Other
}

Resource, IDS_DD_KEY_APPMGR, Keypad
   enum, AppMgr Key, IDEL_KEYPAD
   HELP
      Is there a dedicated key for launching BREW AppManager, select that
      key from the list.  If the key is not listed, select Other and enter
      the key value in the Comment field.

      If there is not a dedicated key for launching BREW AppManager, select
      None.
   }
}
Resource, IDS_DD_BAS_SKEY, Keypad
   enum, Simultaneous Keypress, IDEL_LABEL_YESNO
   HELP
      Are simultaneous keypresses supported on the device?
   }
}
Resource, IDS_DD_KEYGUARD, Keypad
   enum, Keyguard support, IDEL_LABEL_YESNO
   HELP
      Is keyguard supported on the device?
   }
}
Resource, IDS_DD_AUD_VOL_KEY, Keypad
   enum, Volume Keys, IDEL_LABEL_YESNO
   HELP
      Are there volume keys on the device? 
   }
}
EnumList, IDEL_KEYCODES
   57377,AVK_0
   57378,AVK_1
   57379,AVK_2
   57380,AVK_3
   57381,AVK_4
   57382,AVK_5
   57383,AVK_6
   57384,AVK_7
   57385,AVK_8
   57386,AVK_9
   57387,AVK_STAR
   57388,AVK_POUND
   57389,AVK_POWER
   57390,AVK_END
   57391,AVK_SEND
   57392,AVK_CLR
   57393,AVK_UP
   57394,AVK_DOWN
   57395,AVK_LEFT
   57396,AVK_RIGHT
   57397,AVK_SELECT
   57398,AVK_SOFT1
   57399,AVK_SOFT2
   57400,AVK_SOFT3
   57401,AVK_SOFT4
   57402,AVK_FUNCTION1
   57403,AVK_FUNCTION2
   57404,AVK_FUNCTION3
   57405,AVK_FUNCTION
   57406,AVK_MENU
   57407,AVK_INFO
   57408,AVK_SHIFT
   57409,AVK_MESSAGE
   57410,AVK_MUTE
   57411,AVK_STORE
   57412,AVK_RECALL
   57413,AVK_PUNC1
   57414,AVK_PUNC2
   57415,AVK_VOLUME_UP
   57416,AVK_VOLUME_DOWN
   57417,AVK_WEB_ACCESS
   57418,AVK_VOICE_MEMO
   57419,AVK_SPEAKER
   57420,AVK_TAP
   57421,AVK_PTT
   57422,AVK_LSHIFT
   57423,AVK_RSHIFT
   57424,AVK_LCTRL
   57425,AVK_RCTRL
   57426,AVK_LALT
   57427,AVK_RALT
   57428,AVK_CAPLK
   57429,AVK_SCRLK
   57430,AVK_NUMLK
   57431,AVK_LNGHANGUL
   57432,AVK_LNGJUNJA
   57433,AVK_LNGFIN
   57434,AVK_LNGHANJA
   57435,AVK_PRSCRN
   57436,AVK_BREAK
   57437,AVK_TXINSERT
   57438,AVK_TXDELETE
   57439,AVK_TXHOME
   57440,AVK_TXEND
   57441,AVK_TXPGUP
   57442,AVK_TXPGDOWN
   57443,AVK_GP_1   
   57444,AVK_GP_2   
   57445,AVK_GP_3   
   57446,AVK_GP_4   
   57447,AVK_GP_5   
   57448,AVK_GP_6   
   57449,AVK_GP_SL  
   57450,AVK_GP_SR  
   57451,AVK_CAMERA       
   57452,AVK_VIDEO_PHONE
   57453,AVK_APP_SWITCH
}

#<!--_______________________________________
#                Audio
#_______________________________________-->
EnumList, IDEL_HEADSET
   None, None
   Stereo, Stereo
   Mono, Mono
}

Resource, IDS_DD_AUD_STR_SPK, Audio
   enum, Headset Port, IDEL_HEADSET
   HELP
      Select the type of headset port available to BREW (stereo or mono).  Select
      None if no headset port is available to BREW.
   }
}
Resource, IDS_DD_AUD_VIB, Audio
   enum, Vibrator, IDEL_LABEL_YESNO
   HELP
      Is a vibrator available to BREW?  This should match the value returned
      by ISHELL_GetDeviceInfo().
   }
}
Resource, IDS_DD_AUD_RINGER_SPK, Audio
   enum, Ringer only speaker, IDEL_LABEL_YESNO
   HELP
      Is the Ringer-only speaker available to BREW?
   }
}
Resource, IDS_DD_AUD_FARFLD_SPK, Audio
   enum, Far field speaker, IDEL_LABEL_YESNO
   HELP
      Is the far-field speaker available to BREW?
   }
}

#<!--=================================================================
#        Media Formats
#=================================================================-->
Resource, IDS_DD_MULTIMEDIA_VERSION, Media Types
   string, Multimedia File Version
	 HELP
	    Does the device support a non-CMX Multimedia file format? If so enter
			the format and version number. Also enter any types not supported in the
			Comments
   }
} 

#<!--=================================================================
#        Application Support
#=================================================================-->
EnumList, IDEL_ARCHITECTURE
   0, Little Endian
   1, Big Endian
}

Resource, IDS_DD_BAS_ARCH, Application Support
   enum, Architecture, IDEL_ARCHITECTURE
   HELP
      Select the architecture of the processor running brew, little-endian
      or big-endian.
   }
}
Resource, IDS_DD_BAS_COMP_NAME, Application Support
   string, Compiler Name and Version
   HELP
      Enter the name and version of the compiler recommended to build BREW
      application software.  For example, ADS 1.2.
   }
}
Resource, IDS_DD_BAS_COMP_FLAGS, Application Support
   string, Compiler Flags
   HELP
      List any special compiler flags needed to build BREW application
      software to run on this device.  For example, -bigend -fy.  Document
      the meaning and reason for each compiler flag in the Comment section.
   }
}
Resource, IDS_DD_DATA_PRCK_VC, Application Support
   enum, Voice Call Privacy Check, IDEL_LABEL_YESNO
   HELP
      Is the user prompted before a voice call is made?
   }
}
Resource, IDS_DD_DATA_PRCK_GPSFIX, Application Support
   enum, GPS Privacy Check, IDEL_LABEL_YESNO
   HELP
      Is the user prompted before a GPS fix is made?
   }
}
Resource, IDS_DD_BAS_DISP_ANNUN, Application Support
   enum, Annunciators Display, IDEL_LABEL_YESNO
   HELP
      Are the same annunciators which are active before launching BREW also
      visible in BREW?  Document any exceptions or special cases in the 
      Comment field.
   }
}
Resource, IDS_DD_BAS_BREW_ANNUN_MSG, Application Support
   enum, Message annunciator, IDEL_LABEL_YESNO
   HELP
      Can the Message annunciator be controlled through BREW?
   }
}
Resource, IDS_DD_BAS_BREW_ANNUN_NET_MSG, Application Support
   enum, Net Message annunciator, IDEL_LABEL_YESNO
   HELP
      Can the Net Message annunciator be controlled through BREW?
   }
}
Resource, IDS_DD_BAS_BREW_ANNUN_ALARMCLOCK, Application Support
   enum, Alarm annunciator, IDEL_LABEL_YESNO
   HELP
      Can the Alarm annunciator be controlled through BREW?
   }
}
Resource, IDS_DD_BAS_BREW_ANNUN_NET_LOCK, Application Support
   enum, Net Lock annunciator, IDEL_LABEL_YESNO
   HELP
      Can the Net Lock annunciator be controlled through BREW?
   }
}
Resource, IDS_DD_BAS_BREW_ANNUN_STOPWATCH, Application Support
   enum, Stopwatch annunciator, IDEL_LABEL_YESNO
   HELP
      Can the Stopwatch annunciator be controlled through BREW?
   }
}
Resource, IDS_DD_BAS_BREW_ANNUN_COUNTDOWN, Application Support
   enum, Countdown annunciator, IDEL_LABEL_YESNO
   HELP
      Can the Countdown annunciator be controlled through BREW?
   }
}
Resource, IDS_DD_BAS_BREW_ANNUN_ANNUN_SILENCEALL, Application Support
   enum, Silence All annunciator, IDEL_LABEL_YESNO
   HELP
      Can the Silence All annunciator be controlled through BREW?
   }
}
Resource, IDS_DD_NATIVE_NOTIFIER, Application Support
   enum, Idle Native Notifier, IDEL_LABEL_YESNO
   HELP
      Are native notifications that allows a user applet to register to be 
      notified when the device enters / exits the IDLE screen sent to BREW?
   }
}

Resource, IDS_DD_APP_LIST, Preloaded Applications
   complex, Preloaded Applications, 1, 0, none, ,
      string, Class ID
   }
   HELP
      List any preloaded applications on the device by entering their Class 
      IDs (decimal or hex).  Enter the text name or description of each
      application in the Comment field.
      
      Enter "none" if no applications are preloaded.
   }
}

Resource, IDS_DD_PRE_EXT_IDS, Preloaded Extensions
   complex, Developer Extensions, 1, 0, none, ,
      string, Class ID
   }
   HELP
      List any preloaded developer extensions on the device by entering their
      Class IDs (decimal or hex).  Enter the text name or description of each
      extension in the Comment field.
      
      Enter "none" if no developer extensions are preloaded.
   }
}

Resource, IDS_DD_CARR_EXT_LIST, Preloaded Extensions
   complex, Carrier Extensions, 1, 0, none, ,
      string, Class ID
   }
   HELP
      List any preloaded carrier extensions on the device by entering their
      Class IDs (decimal or hex).  Enter the text name or description of each
      extension in the Comment field.
      
      Enter "none" if no carrier extensions are preloaded.
   }
}
Resource, IDS_DD_OEM_EXT_LIST, Preloaded Extensions
   complex, OEM Extensions, 1, 0, none, ,
      string, Class ID
   }
   HELP
      List any preloaded OEM extensions on the device by entering their
      Class IDs (decimal or hex).  Enter the text name or description of each
      extension in the Comment field.
      
      Enter "none" if no OEM extensions are preloaded.
   }
}
Resource, IDS_DD_LANG_LIST, Application Support
   string, Language list, , |
   HELP
      List the languages supported by this device when in BREW.  For example:
      English, Spanish.
   }
}


#<!--=================================================================
#        Text Entry
#=================================================================-->

# note a common ASCII character 's' is specified as a delimiter so no
# symbols are treated as such.
Resource, IDS_DD_TXT_SYM, Text Entry
   string, Symbols, , s
   HELP
      Enter all symbols supported by the BREW text input control.  List
      only symbols.  Do not use spaces, commas, or other characters
      as delimiters.  For example: -.&'()_!?{}[]^;></\@~*#%":+=
   }
}
Resource, IDS_DD_TXT_PRED_ENTRY, Text Entry
   enum, Predictive entry, IDEL_LABEL_YESNO
   HELP
      Is predictive text entry (e.g. T9, eZiText) supported on this
      device?  List the type in Comment field.
   }
}
Resource, IDS_DD_TXT_MODES, Text Entry
   string, Modes, , |
   HELP
      List all text input modes available in the BREW text input control.
   }
}

#<!--=================================================================
#        Font
#=================================================================-->
EnumList, IDEL_WIDTH_TYPE
   0, Fixed
   1, Dynamic
}

Resource, IDS_DD_FONT_NORMAL_ASCENT, Font
   uint32, Normal Font - Ascent
   HELP
      The height of the font above the baseline in pixels.
   }
}
Resource, IDS_DD_FONT_NORMAL_DESCENT, Font
   uint32, Normal Font - Descent
   HELP
      The height of the font below the baseline in pixels.
   }
}
Resource, IDS_DD_FONT_NORMAL_WIDTH, Font
   enum, Normal Font Width, IDEL_WIDTH_TYPE
   HELP
      Select Fixed or Dynamic (variable) width for ASCII characters.
      
      NOTE: This entry is used by PEK 2.1 and 3.0.0.  Later versions of
      PEK use the Normal Font ASCII Character Width and Normal Font Asian
      Character Width fields.
   }
}
Resource, IDS_DD_FONT_NORMAL_WIDTH_ASCII, Font
   string, Normal Font ASCII Character Width
   HELP
      If normal ASCII characters have a variable (dynamic) width (also called a 
      proportional font), enter 0.

      If normal ASCII characters have a fixed width (also called a monospace font),
      enter the width of a character in pixels.

      If normal ASCII characters are not supported enter -1.
   }
}
Resource, IDS_DD_FONT_NORMAL_WIDTH_ASIAN, Font
   string, Normal Font Asian Character Width
   HELP
      If normal Asian characters have a variable (dynamic) width (also called a 
      proportional font), enter 0.

      If normal Asian characters have a fixed width (also called a monospace font),
      enter the width of a character in pixels.

      If normal Asian characters are not supported enter -1.
   }
}
Resource, IDS_DD_FONT_NORMAL_GLYPH, Font
   complex, Supported Glyphs, 1, ,
      string, Glyph / Glyph Range
   }
   HELP
      Enter the Unicode value for each glyph supported on the
      device.  You many enter individual glyphs or glyph ranges.  To specify a
      glyph range, using the format <starting glyph >-<ending glyph>.  For
      example, 0x5b-0x60.  Values may be entered in decimal or hex format.

      It is expected that the normal, bold, and large fonts will all support
      the same glyphs.  Document any discrepancies in the Comment field.
   }
}
Resource, IDS_DD_FONT_BOLD_ASCENT, Font
   uint32, Bold Font - Ascent
   HELP
      The height of the font above the baseline in pixels.
   }
}
Resource, IDS_DD_FONT_BOLD_DESCENT, Font
   uint32, Bold Font - Descent
   HELP
      The height of the font below the baseline in pixels.
   }
}
Resource, IDS_DD_FONT_BOLD_WIDTH, Font
   enum, Bold Font Width, IDEL_WIDTH_TYPE
   HELP
      Select Fixed or Dynamic (variable) width for ASCII characters.
      
      NOTE: This entry is used by PEK 2.1 and 3.0.0.  Later versions of
      PEK use the  Bold Font ASCII Character Width and Bold Font Asian
      Character Width fields.
   }
}
Resource, IDS_DD_FONT_BOLD_WIDTH_ASCII, Font
   string, Bold Font ASCII Character Width
   HELP
      If bold ASCII characters have a variable (dynamic) width (also called a 
      proportional font), enter 0.

      If bold ASCII characters have a fixed width (also called a monospace font),
      enter the width of a character in pixels.

      If bold ASCII characters are not supported enter -1.
   }
}
Resource, IDS_DD_FONT_BOLD_WIDTH_ASIAN, Font
   string, Bold Font Asian Character Width
   HELP
      If bold Asian characters have a variable (dynamic) width (also called a 
      proportional font), enter 0.

      If bold Asian characters have a fixed width (also called a monospace font),
      enter the width of a character in pixels.

      If bold Asian characters are not supported enter -1.
   }
}
Resource, IDS_DD_FONT_LARGE_ASCENT, Font
   uint32, Large Font - Ascent
   HELP
      The height of the font above the baseline in pixels.
   }
}
Resource, IDS_DD_FONT_LARGE_DESCENT, Font
   uint32, Large Font - Descent
   HELP
      The height of the font below the baseline in pixels.
   }
}
Resource, IDS_DD_FONT_LARGE_WIDTH, Font
   enum, Large Font Width, IDEL_WIDTH_TYPE
   HELP
      Select Fixed or Dynamic (variable) width for ASCII characters.
      
      NOTE: This entry is used by PEK 2.1 and 3.0.0.  Later versions of
      PEK use the Large Font ASCII Character Width and Large Font Asian
      Character Width fields.
   }
}
Resource, IDS_DD_FONT_LARGE_WIDTH_ASCII, Font
   string, Large Font ASCII Character Width
   HELP
      If large ASCII characters have a variable (dynamic) width (also called a 
      proportional font), enter 0.

      If large ASCII characters have a fixed width (also called a monospace font),
      enter the width of a character in pixels.

      If large ASCII characters are not supported enter -1.
   }
}
Resource, IDS_DD_FONT_LARGE_WIDTH_ASIAN, Font
   string, Large Font Asian Character Width
   HELP
      If large Asian characters have a variable (dynamic) width (also called a 
      proportional font), enter 0.

      If large Asian characters have a fixed width (also called a monospace font),
      enter the width of a character in pixels.

      If large Asian characters are not supported enter -1.
   }
}

EnumList, IDEL_ENCODING
   UNICODE
   KSC5601 
   S-JIS
   CP949
}
Resource, IDS_DD_ENCODING, Font
   enum, Encoding, IDEL_ENCODING
   HELP
      Specify the encoding type for fonts made available to BREW.
   }   
}
Resource, IDS_DD_FONT_MONOBITMAPFONTS, Font
   enum, Monochrome bitmap fonts, IDEL_YESNO
   HELP
      If all of the fonts on the device are represented by monochrome bitmaps,
      enter Yes.  If one or more of the fonts is not, enter
      No.  For example, if a font is a vector font, uses multiple colors,
      or uses alpha blending or antialiasing, enter No.
   }
}

#<!--=================================================================
#        Position Determination
#=================================================================-->
EnumList, IDEL_LBS_AUTH_TYPE
   0, Trusted
   1, V1 Non-trusted
   2, V2 Non-trusted
   3, Other
}
Resource, IDS_DD_POS_GPS, Position Determination
   enum, GPS Supported, IDEL_LABEL_YESNO
   HELP
      Is GPS-based position determination available to BREW?
   }
}
Resource, IDS_DD_POS_SECTOR, Position Determination
   enum, Sector-based Supported, IDEL_LABEL_YESNO
   HELP
      Is sector-based position determination available to BREW?
   }
}
Resource, IDS_DD_POS_LBS_AUTH_POLICY, Position Determination
   enum, Device Support for Network LBS Authorization Policy, IDEL_LBS_AUTH_TYPE
   HELP
      The network authorization policy is determined by the carrier.  
      Select the authorization policy supported by the device for LBS (V1, V2, or Other). 
      Note that applications on Trusted LBS networks do not go through authorization. "Other" is the category for any authorization mechanism not described in the list, which shall be further described or identified in the comments. 
      This entry is not applicable if the device does not support GPS LBS.
   }
}
#<!--=================================================================
#        Exception LIst
#=================================================================-->
Resource, IDS_DD_EXCEPT_LIST, OEM Exceptions
   complex, Exceptions, 0, , ,
      string, Function
      string, Interface
      string, Reason
   }
   HELP
      For each exception, enter the following: 
      
      Function - The name of function at the AEE layer that has not been
      implemented.

      Interface - The name of interface that the function belongs to.

      Reason - The reason why the function/interface has not been implemented.
   }
}

#<!--=================================================================
#        Bluetooth
#=================================================================-->
Resource, IDS_DD_BLUETOOTH_SUPP, Bluetooth
   enum, Bluetooth Supported, IDEL_LABEL_YESNO
   HELP
      Are Bluetooth Headsets supported as an ISound device type by the
			device?
   }
}

#<!--=================================================================
#        Ringer
#=================================================================-->
Resource, IDS_DD_RINGER_MAX_SIZE, Ringer
   uint32, Max Ringer Size
   HELP
      Specify the maximum ringer size in bytes or 0 for no limit.
   }
}
Resource, IDS_DD_RINGER_FORMATS, Ringer
   complex, Supported Formats
      string, ID
      string, File Extension
   }
   HELP
      For each media formats supported for Ringers, list the following:

      ID - The AEESoundPlayerFile ID for the format (decimal or hex).  For
      example, 128 or 0x80.
      
      File Extension -  The file name extension associated with the ID.  For
      example, for an ID of 1 you would typically enter "mid".

      Note 1: pmd = CMX: Compact MIDI, SAF, PNG, JPEG, QCELP, ADPCM.
      
      Note 2: The ID (1, 2, and 3 in the example) is the value returned in
      pwFormats by IRINGERMGR_GetFormats().
   }
}
Resource, IDS_DD_RINGER_MAX_COUNT, Ringer
   uint32, Max Ringers
   HELP
      Specify the maximum number of ringers that can be placed on the device
      (on many handsets this is the maximum number of files that may be 
      stored in the ringer directory).  Enter 0 if there is no limit.
   }
}
Resource, IDS_DD_RINGER_CATEGORIES, Ringer
   complex, Categories
      string, ID
      string, Name
   }
   HELP
      List the categories to which ringers can be assigned by developers.  For
      each category, enter the following:

      ID - The AEERingerCatID value.  For example, 1.  If ringer categories
      are not supported, enter 0.
      
      Name - The name of the ringer category.  For example, "Friends".  If
      ringer categories are not supported, enter "All".
   }
}
Resource, IDS_DD_RINGER_NATIVE_UI_ACTIVATE, Ringer
   enum, Native UI Activate, IDEL_LABEL_YESNO
   HELP
      Can ringers created by BREW be activated using the native UI?
   }
}
Resource, IDS_DD_RINGER_DEL_NATIVE, Ringer
   enum, Native UI Delete, IDEL_LABEL_YESNO
   HELP
      Can ringers created by BREW be deleted using the native UI?
   }
}
Resource, IDS_DD_RINGER_FILE_MENU, Ringer
   enum, Integrated Ringer File Menu, IDEL_LABEL_YESNO
   HELP
      Is it possible to manage native and BREW downloaded ringers from the
      same native UI?
   }
}
EnumList, IDEL_LABEL_RINGER_AUDIO_PATH
   Ringer-only Speaker, Ringer-only Speaker
   Far-Field Speaker, Far-Field Speaker
   Earpiece Speaker, Earpiece Speaker
   Other, Other
}

Resource, IDS_DD_RINGER_AUDIO_PATH, Ringer
   enum, Audio playback path, IDEL_LABEL_RINGER_AUDIO_PATH
   HELP
      Select the ringer audio playback path.  If other, please explain
      in the Comment field.
   }
}


#<!--=================================================================
#        AddrBook
#=================================================================-->
EnumList, IDEL_ADDR_FIELD_TYPE
   0, AEEDB_FT_NONE
   1, AEEDB_FT_BYTE
   2, AEEDB_FT_WORD
   3, AEEDB_FT_DWORD
   4, AEEDB_FT_STRING
   5, AEEDB_FT_BINARY
   6, AEEDB_FT_PHONE
   7, AEEDB_FT_BITMAP
   8, AEEDB_FT_MAX
}

EnumList, IDEL_ADDR_CAT
	0,      AEE_ADDR_CAT_NONE    
	1,      AEE_ADDR_CAT_PERSONAL
	2,      AEE_ADDR_CAT_BUSINESS
	32768,  AEE_ADDR_CAT_USER + 0
	32769,  AEE_ADDR_CAT_USER + 1
	32770,  AEE_ADDR_CAT_USER + 2
	32771,  AEE_ADDR_CAT_USER + 3
	32772,  AEE_ADDR_CAT_USER + 4
	32773,  AEE_ADDR_CAT_USER + 5
	32774,  AEE_ADDR_CAT_USER + 6
	32775,  AEE_ADDR_CAT_USER + 7
	32776,  AEE_ADDR_CAT_USER + 8
	32777,  AEE_ADDR_CAT_USER + 9
	32778,  AEE_ADDR_CAT_USER + 10
	32779,  AEE_ADDR_CAT_USER + 11
	32780,  AEE_ADDR_CAT_USER + 12
	32781,  AEE_ADDR_CAT_USER + 13
	32782,  AEE_ADDR_CAT_USER + 14
	32783,  AEE_ADDR_CAT_USER + 15
	32784,  AEE_ADDR_CAT_USER + 16
	32785,  AEE_ADDR_CAT_USER + 17
	32786,  AEE_ADDR_CAT_USER + 18
	32787,  AEE_ADDR_CAT_USER + 19
	32788,  AEE_ADDR_CAT_USER + 20
	32789,  AEE_ADDR_CAT_USER + 21
	32790,  AEE_ADDR_CAT_USER + 22
	32791,  AEE_ADDR_CAT_USER + 23
	32792,  AEE_ADDR_CAT_USER + 24
	32793,  AEE_ADDR_CAT_USER + 25
	32794,  AEE_ADDR_CAT_USER + 26
	32795,  AEE_ADDR_CAT_USER + 27
	32796,  AEE_ADDR_CAT_USER + 28
	32797,  AEE_ADDR_CAT_USER + 29
	32798,  AEE_ADDR_CAT_USER + 30
	32799,  AEE_ADDR_CAT_USER + 31
	32800,  AEE_ADDR_CAT_USER + 32
	32801,  AEE_ADDR_CAT_USER + 33
	32802,  AEE_ADDR_CAT_USER + 34
	32803,  AEE_ADDR_CAT_USER + 35
	32804,  AEE_ADDR_CAT_USER + 36
	32805,  AEE_ADDR_CAT_USER + 37
	32806,  AEE_ADDR_CAT_USER + 38
	32807,  AEE_ADDR_CAT_USER + 39
	32808,  AEE_ADDR_CAT_USER + 40
	32809,  AEE_ADDR_CAT_USER + 41
	32810,  AEE_ADDR_CAT_USER + 42
	32811,  AEE_ADDR_CAT_USER + 43
	32812,  AEE_ADDR_CAT_USER + 44
	32813,  AEE_ADDR_CAT_USER + 45
	32814,  AEE_ADDR_CAT_USER + 46
	32815,  AEE_ADDR_CAT_USER + 47
	32816,  AEE_ADDR_CAT_USER + 48
	32817,  AEE_ADDR_CAT_USER + 49
	32818,  AEE_ADDR_CAT_USER + 50
	65280,  AEE_ADDR_CAT_USER_DEFINED + 0
	65281,  AEE_ADDR_CAT_USER_DEFINED + 1
	65282,  AEE_ADDR_CAT_USER_DEFINED + 2
	65283,  AEE_ADDR_CAT_USER_DEFINED + 3
	65284,  AEE_ADDR_CAT_USER_DEFINED + 4
	65285,  AEE_ADDR_CAT_USER_DEFINED + 5
	65286,  AEE_ADDR_CAT_USER_DEFINED + 6
	65287,  AEE_ADDR_CAT_USER_DEFINED + 7
	65288,  AEE_ADDR_CAT_USER_DEFINED + 8
	65289,  AEE_ADDR_CAT_USER_DEFINED + 9
	65290,  AEE_ADDR_CAT_USER_DEFINED + 10
	65291,  AEE_ADDR_CAT_USER_DEFINED + 11
	65292,  AEE_ADDR_CAT_USER_DEFINED + 12
	65293,  AEE_ADDR_CAT_USER_DEFINED + 13
	65294,  AEE_ADDR_CAT_USER_DEFINED + 14
	65295,  AEE_ADDR_CAT_USER_DEFINED + 15
	65296,  AEE_ADDR_CAT_USER_DEFINED + 16
	65297,  AEE_ADDR_CAT_USER_DEFINED + 17
	65298,  AEE_ADDR_CAT_USER_DEFINED + 18
	65299,  AEE_ADDR_CAT_USER_DEFINED + 19
	65300,  AEE_ADDR_CAT_USER_DEFINED + 20
	65301,  AEE_ADDR_CAT_USER_DEFINED + 21
	65302,  AEE_ADDR_CAT_USER_DEFINED + 22
	65303,  AEE_ADDR_CAT_USER_DEFINED + 23
	65304,  AEE_ADDR_CAT_USER_DEFINED + 24
	65305,  AEE_ADDR_CAT_USER_DEFINED + 25
	65306,  AEE_ADDR_CAT_USER_DEFINED + 26
	65307,  AEE_ADDR_CAT_USER_DEFINED + 27
	65308,  AEE_ADDR_CAT_USER_DEFINED + 28
	65309,  AEE_ADDR_CAT_USER_DEFINED + 29
	65310,  AEE_ADDR_CAT_USER_DEFINED + 30
	65311,  AEE_ADDR_CAT_USER_DEFINED + 31
	65312,  AEE_ADDR_CAT_USER_DEFINED + 32
	65313,  AEE_ADDR_CAT_USER_DEFINED + 33
	65314,  AEE_ADDR_CAT_USER_DEFINED + 34
	65315,  AEE_ADDR_CAT_USER_DEFINED + 35
	65316,  AEE_ADDR_CAT_USER_DEFINED + 36
	65317,  AEE_ADDR_CAT_USER_DEFINED + 37
	65318,  AEE_ADDR_CAT_USER_DEFINED + 38
	65319,  AEE_ADDR_CAT_USER_DEFINED + 39
	65320,  AEE_ADDR_CAT_USER_DEFINED + 40
	65321,  AEE_ADDR_CAT_USER_DEFINED + 41
	65322,  AEE_ADDR_CAT_USER_DEFINED + 42
	65323,  AEE_ADDR_CAT_USER_DEFINED + 43
	65324,  AEE_ADDR_CAT_USER_DEFINED + 44
	65325,  AEE_ADDR_CAT_USER_DEFINED + 45
	65326,  AEE_ADDR_CAT_USER_DEFINED + 46
	65327,  AEE_ADDR_CAT_USER_DEFINED + 47
	65328,  AEE_ADDR_CAT_USER_DEFINED + 48
	65329,  AEE_ADDR_CAT_USER_DEFINED + 49
	65330,  AEE_ADDR_CAT_USER_DEFINED + 50
}
EnumList, IDEL_ADDR_FIELD
	0,      AEE_ADDRFIELD_NONE         
	1,      AEE_ADDRFIELD_FIRSTNAME    
	2,      AEE_ADDRFIELD_MIDDLENAME   
	3,      AEE_ADDRFIELD_LASTNAME     
	4,      AEE_ADDRFIELD_NICKNAME     
	5,      AEE_ADDRFIELD_NAME         
	6,      AEE_ADDRFIELD_ORG          
	7,      AEE_ADDRFIELD_JOBTITLE     
	8,      AEE_ADDRFIELD_ADDRESS      
	9,      AEE_ADDRFIELD_CITY         
	10,     AEE_ADDRFIELD_STATE        
	11,     AEE_ADDRFIELD_COUNTRY      
	12,     AEE_ADDRFIELD_ZIPCODXE     
	13,     AEE_ADDRFIELD_URL          
	14,     AEE_ADDRFIELD_DEPARTMENT   
	15,     AEE_ADDRFIELD_EMAIL        
	16,     AEE_ADDRFIELD_GENDER       
	17,     AEE_ADDRFIELD_PHONE_WORK   
	18,     AEE_ADDRFIELD_PHONE_HOME   
	19,     AEE_ADDRFIELD_PHONE_FAX    
	20,     AEE_ADDRFIELD_PHONE_VOICE  
	21,     AEE_ADDRFIELD_PHONE_PREF   
	22,     AEE_ADDRFIELD_PHONE_CELL   
	23,     AEE_ADDRFIELD_PHONE_PAGER  
	24,     AEE_ADDRFIELD_PHONE_GENERIC
	25,     AEE_ADDRFIELD_PHONE_OTHER  
	26,     AEE_ADDRFIELD_BDAY         
	27,     AEE_ADDRFIELD_SORTSTRING
	28,     AEE_ADDRFIELD_NOTES
   29,     AEE_ADDRFIELD_SIP_URL
	30,     AEE_ADDRFIELD_DIAL_STRING
	31,     AEE_ADDRFIELD_INDEX
	32,     AEE_ADDRFIELD_VOICETAG
	33,     AEE_ADDRFIELD_RINGTONE
	34,     AEE_ADDRFIELD_SPEED_DIAL
	35,     AEE_ADDRFIELD_NAMESUFFIX
	36,     AEE_ADDRFIELD_NAMEPREFIX
	37,     AEE_ADDRFIELD_OTHERNAME
	38,     AEE_ADDRFIELD_PHOTO
	39,     AEE_ADDRFIELD_PHOTOURL
	40,     AEE_ADDRFIELD_POBOX
	41,     AEE_ADDRFIELD_ADDREXTRA
	42,     AEE_ADDRFIELD_STREET
	43,     AEE_ADDRFIELD_UID
	44,     AEE_ADDRFIELD_PUBLICKEY
	45,     AEE_ADDRFIELD_PUBLICKEYSTRING
   28672,  AEE_ADDRFIELD_ADMIN
   28673,  AEE_ADDRFIELD_TIME_STAMP
   28674,  AEE_ADDRFIELD_LAST_CONNECT
   28675,  AEE_ADDRFIELD_CONNECT_COUNT
	32768,  AEE_ADDRFIELD_USER + 0
	32769,  AEE_ADDRFIELD_USER + 1
	32770,  AEE_ADDRFIELD_USER + 2
	32771,  AEE_ADDRFIELD_USER + 3
	32772,  AEE_ADDRFIELD_USER + 4
	32773,  AEE_ADDRFIELD_USER + 5
	32774,  AEE_ADDRFIELD_USER + 6
	32775,  AEE_ADDRFIELD_USER + 7
	32776,  AEE_ADDRFIELD_USER + 8
	32777,  AEE_ADDRFIELD_USER + 9
	32778,  AEE_ADDRFIELD_USER + 10
	32779,  AEE_ADDRFIELD_USER + 11
	32780,  AEE_ADDRFIELD_USER + 12
	32781,  AEE_ADDRFIELD_USER + 13
	32782,  AEE_ADDRFIELD_USER + 14
	32783,  AEE_ADDRFIELD_USER + 15
	32784,  AEE_ADDRFIELD_USER + 16
	32785,  AEE_ADDRFIELD_USER + 17
	32786,  AEE_ADDRFIELD_USER + 18
	32787,  AEE_ADDRFIELD_USER + 19
	32788,  AEE_ADDRFIELD_USER + 20
	32789,  AEE_ADDRFIELD_USER + 21
	32790,  AEE_ADDRFIELD_USER + 22
	32791,  AEE_ADDRFIELD_USER + 23
	32792,  AEE_ADDRFIELD_USER + 24
	32793,  AEE_ADDRFIELD_USER + 25
	32794,  AEE_ADDRFIELD_USER + 26
	32795,  AEE_ADDRFIELD_USER + 27
	32796,  AEE_ADDRFIELD_USER + 28
	32797,  AEE_ADDRFIELD_USER + 29
	32798,  AEE_ADDRFIELD_USER + 30
	32799,  AEE_ADDRFIELD_USER + 31
	32800,  AEE_ADDRFIELD_USER + 32
	32801,  AEE_ADDRFIELD_USER + 33
	32802,  AEE_ADDRFIELD_USER + 34
	32803,  AEE_ADDRFIELD_USER + 35
	32804,  AEE_ADDRFIELD_USER + 36
	32805,  AEE_ADDRFIELD_USER + 37
	32806,  AEE_ADDRFIELD_USER + 38
	32807,  AEE_ADDRFIELD_USER + 39
	32808,  AEE_ADDRFIELD_USER + 40
	32809,  AEE_ADDRFIELD_USER + 41
	32810,  AEE_ADDRFIELD_USER + 42
	32811,  AEE_ADDRFIELD_USER + 43
	32812,  AEE_ADDRFIELD_USER + 44
	32813,  AEE_ADDRFIELD_USER + 45
	32814,  AEE_ADDRFIELD_USER + 46
	32815,  AEE_ADDRFIELD_USER + 47
	32816,  AEE_ADDRFIELD_USER + 48
	32817,  AEE_ADDRFIELD_USER + 49
	32818,  AEE_ADDRFIELD_USER + 50
	65280,  AEE_ADDRFIELD_USER_DEFINED + 0
	65281,  AEE_ADDRFIELD_USER_DEFINED + 1
	65282,  AEE_ADDRFIELD_USER_DEFINED + 2
	65283,  AEE_ADDRFIELD_USER_DEFINED + 3
	65284,  AEE_ADDRFIELD_USER_DEFINED + 4
	65285,  AEE_ADDRFIELD_USER_DEFINED + 5
	65286,  AEE_ADDRFIELD_USER_DEFINED + 6
	65287,  AEE_ADDRFIELD_USER_DEFINED + 7
	65288,  AEE_ADDRFIELD_USER_DEFINED + 8
	65289,  AEE_ADDRFIELD_USER_DEFINED + 9
	65290,  AEE_ADDRFIELD_USER_DEFINED + 10
	65291,  AEE_ADDRFIELD_USER_DEFINED + 11
	65292,  AEE_ADDRFIELD_USER_DEFINED + 12
	65293,  AEE_ADDRFIELD_USER_DEFINED + 13
	65294,  AEE_ADDRFIELD_USER_DEFINED + 14
	65295,  AEE_ADDRFIELD_USER_DEFINED + 15
	65296,  AEE_ADDRFIELD_USER_DEFINED + 16
	65297,  AEE_ADDRFIELD_USER_DEFINED + 17
	65298,  AEE_ADDRFIELD_USER_DEFINED + 18
	65299,  AEE_ADDRFIELD_USER_DEFINED + 19
	65300,  AEE_ADDRFIELD_USER_DEFINED + 20
	65301,  AEE_ADDRFIELD_USER_DEFINED + 21
	65302,  AEE_ADDRFIELD_USER_DEFINED + 22
	65303,  AEE_ADDRFIELD_USER_DEFINED + 23
	65304,  AEE_ADDRFIELD_USER_DEFINED + 24
	65305,  AEE_ADDRFIELD_USER_DEFINED + 25
	65306,  AEE_ADDRFIELD_USER_DEFINED + 26
	65307,  AEE_ADDRFIELD_USER_DEFINED + 27
	65308,  AEE_ADDRFIELD_USER_DEFINED + 28
	65309,  AEE_ADDRFIELD_USER_DEFINED + 29
	65310,  AEE_ADDRFIELD_USER_DEFINED + 30
	65311,  AEE_ADDRFIELD_USER_DEFINED + 31
	65312,  AEE_ADDRFIELD_USER_DEFINED + 32
	65313,  AEE_ADDRFIELD_USER_DEFINED + 33
	65314,  AEE_ADDRFIELD_USER_DEFINED + 34
	65315,  AEE_ADDRFIELD_USER_DEFINED + 35
	65316,  AEE_ADDRFIELD_USER_DEFINED + 36
	65317,  AEE_ADDRFIELD_USER_DEFINED + 37
	65318,  AEE_ADDRFIELD_USER_DEFINED + 38
	65319,  AEE_ADDRFIELD_USER_DEFINED + 39
	65320,  AEE_ADDRFIELD_USER_DEFINED + 40
	65321,  AEE_ADDRFIELD_USER_DEFINED + 41
	65322,  AEE_ADDRFIELD_USER_DEFINED + 42
	65323,  AEE_ADDRFIELD_USER_DEFINED + 43
	65324,  AEE_ADDRFIELD_USER_DEFINED + 44
	65325,  AEE_ADDRFIELD_USER_DEFINED + 45
	65326,  AEE_ADDRFIELD_USER_DEFINED + 46
	65327,  AEE_ADDRFIELD_USER_DEFINED + 47
	65328,  AEE_ADDRFIELD_USER_DEFINED + 48
	65329,  AEE_ADDRFIELD_USER_DEFINED + 49
	65330,  AEE_ADDRFIELD_USER_DEFINED + 50
}

Resource, IDS_DD_MAX_ADDR_COUNT, Address Book
   uint32, Max Entries
   HELP
      Specify the maximum number of entries in the address book.  Enter
      0 if there is no limit.
   }
}
Resource, IDS_DD_ADDR_CAT, PEK 2.1 Compatability
   complex, AddrBook Categories, 1, 0, 0, |
      enum, Category ID, IDEL_ADDR_CAT
   }
   HELP
      NOTE:  This field is provided for PEK 2.1 backward compatibility.
      It is not used by PEK 3.0 and later.

      List each category the device supports.  Refer to AEEAddrBook.h and
      the BREW API Reference for more information.
      
      Category ID - Enter the unique AEEAddrCat value for this category
      in terms of the AEE_ADDR_CAT_xxx macros from AEEAddrBook.h.
      For BREW 2.1, OEM-defined categories begin at
      AEE_ADDR_CAT_USER_DEFINED.  For BREW 3.0 and later, OEM-defined
      categories begin at AEE_ADDR_CAT_USER (AEE_ADDR_CAT_USER_DEFINED
      has been deprecated in BREW 3.0).  If the device does not support
      categories, enter AEE_ADDR_CAT_NONE.
   }
}
Resource, IDS_DD_ADDR_FIELDS, PEK 2.1 Compatability
   complex, AddrBook Fields, 1, 0, 0, |
      enum, Category, IDEL_ADDR_CAT
      enum, Field ID, IDEL_ADDR_FIELD
      uint32, Max Items
      enum, Field Type, IDEL_ADDR_FIELD_TYPE
      enum, Field Search, IDEL_LABEL_YESNO
      enum, Category Search, IDEL_LABEL_YESNO
      enum, Required, IDEL_LABEL_YESNO
   }
   HELP
      NOTE:  This field is provided for PEK 2.1 backward compatibility.
      It is not used by PEK 3.0 and later.

      List each field the device supports, and specify the characteristics
      of each field.  Refer to AEEAddrBook.h and the BREW API Reference
      for more information on the AEEAddrFieldInfo data structure.

      IMPORTANT:  List all fields available in all categories with a category
      of AEE_ADDR_CAT_NONE.
   
      Category - Enter the category this field is available in.  Most
      fields are available in all categories -- these fields must be
      listed once for each category they are available in.
      
      Field ID - Enter the AEEAddrFieldID for this field.  Predefined field
      IDs are at the beginning of the list.  OEM-defined values are at the end
      of the list.  For BREW 2.1, the OEM-defined values begin at
      AEE_ADDRFIELD_USER_DEFINED.  For BREW 3.0 and later, the OEM-defined
      values begin at AEE_ADDRFIELD_USER (AEE_ADDRFIELD_USER_DEFINED is
      deprecated).  AEE_ADDR_FIELD_xxx values are defined in AEEAddrBook.h.
      You may need technical assistance from the developer of OEMAddrBook.c
      to determine these values.

      Field Type - Enter the AEEAddrFieldType for this field.

      Max Items - Enter the maximum allowed number of items of this fieldID
      in each record.  For example, if fieldID is AEE_ADDRFIELD_EMAIL, then 
      maxItems could be 2 if OEM address book supports only a maximum of 2 
      email entries per record.
      
      Field Search - Can a search (EnumRec) be done based on this field?  That
      is, can we make a call to IADDRBOOK_EnumRecInit() to search for all
      records having a specific value for this given field ID.

      Category Search - Can a search (EnumRec) be done based on this field
      within a category?  That is, can we use IADDRBOOK_EnumRecInit() to
      search for all records of a specific category having a specific value for
      this field?

      Required - Is this field required to be present in all records?
   }
}
Resource, IDS_DD_ADDR_CAT_30, Address Book
   complex, Categories, 1, 0, 0, |
      enum, Category ID, IDEL_ADDR_CAT
      string, Category Name
   }
   HELP
      List each category the device supports.  Refer to AEEAddrBook.h and
      the BREW API Reference for more information.
      
      Category ID - Enter the unique AEEAddrCat value for this category
      in terms of the AEE_ADDR_CAT_xxx macros from AEEAddrBook.h.
      For BREW 2.1, OEM-defined categories begin at
      AEE_ADDR_CAT_USER_DEFINED.  For BREW 3.0 and later, OEM-defined
      categories begin at AEE_ADDR_CAT_USER (AEE_ADDR_CAT_USER_DEFINED
      has been deprecated in BREW 3.0).  If the device does not support
      categories, enter AEE_ADDR_CAT_NONE.
      
      Category Name - Enter the text name of this category.  For example:
      Business, Personal, Friends, etc.  If the device does not support
      categories, enter "None".
   }
}
Resource, IDS_DD_ADDR_FIELDS_30, Address Book
   complex, Fields, 1, 0, 0, |
      enum, Category, IDEL_ADDR_CAT
      enum, Field ID, IDEL_ADDR_FIELD
      string, Field Name
      uint32, Max Items
      enum, Field Type, IDEL_ADDR_FIELD_TYPE
      enum, Field Search, IDEL_LABEL_YESNO
      enum, Category Search, IDEL_LABEL_YESNO
      enum, Required, IDEL_LABEL_YESNO
      uint32, Max Length
   }
   HELP
      List each field the device supports, and specify the characteristics
      of each field.  Refer to AEEAddrBook.h and the BREW API Reference
      for more information on the AEEAddrFieldInfo data structure.

      IMPORTANT:  List all fields available in all categories with a category
      of AEE_ADDR_CAT_NONE.
   
      Category - Enter the category this field is available in.  Most
      fields are available in all categories -- these fields must be
      listed once for each category they are available in.
      
      Field Name - Enter the text name of the field.  For example, "Name", 
      "email", "Work Phone", etc.

      Field ID - Enter the AEEAddrFieldID for this field.  Predefined field
      IDs are at the beginning of the list.  OEM-defined values are at the end
      of the list.  For BREW 2.1, the OEM-defined values begin at
      AEE_ADDRFIELD_USER_DEFINED.  For BREW 3.0 and later, the OEM-defined
      values begin at AEE_ADDRFIELD_USER (AEE_ADDRFIELD_USER_DEFINED is
      deprecated).  AEE_ADDR_FIELD_xxx values are defined in AEEAddrBook.h.
      You may need technical assistance from the developer of OEMAddrBook.c
      to determine these values.

      Field Type - Enter the AEEAddrFieldType for this field.

      Max Items - Enter the maximum allowed number of items of this fieldID
      in each record.  For example, if fieldID is AEE_ADDRFIELD_EMAIL, then 
      maxItems could be 2 if OEM address book supports only a maximum of 2 
      email entries per record.

      Field Search - Can a search (EnumRec) be done based on this field?  That
      is, can we make a call to IADDRBOOK_EnumRecInit() to search for all
      records having a specific value for this given field ID.

      Category Search - Can a search (EnumRec) be done based on this field
      within a category?  That is, can we use IADDRBOOK_EnumRecInit() to
      search for all records of a specific category having a specific value for
      this field?

      Required - Is this field required to be present in all records?

      Max Length - Enter the maximum length of this field in units of the
      AEEAddrFieldType.  For example, if this is a string field that can hold
      a maximum of 50 AECHARs, enter 50, not 100 bytes.
   }
}
Resource, IDS_DD_ADDR_USER_DEF_CAT, Address Book
   enum, App Category Definition, IDEL_YESNO
   HELP
      Can a BREW application create a record with an AEEAddrCat that is not
      one of the categories returned by IADDRBOOK_EnumNextCategory()?  Select
      Yes if applications may create records with their own unique 
      categories.  Select No if applications are restricted to the categories
      defined by the OEM.
   }
}
Resource, IDS_DD_ADDR_USER_DEF_FIELD, Address Book
   enum, App Field Definition, IDEL_YESNO
   HELP
      Can a BREW application create an address book field with an AEEAddrFieldID
      that is not one of the field IDs returned by 
      IADDRBOOK_EnumNextFieldsInfo()?  Enter Yes if applications may create 
      their own field IDs.  Enter No if applications are restricted to the field
      IDs defined by the OEM.
   }
}
Resource, IDS_DD_ADDR_REMOVE_ALL_SUPPORTED, Address Book
   enum, RemoveAllRecs Support, IDEL_YESNO
   HELP
      Does the device support the IADDRBOOK_RemoveAllRecs() method?
   }
}

#<!--=================================================================
#        AddrBook RUIM
#=================================================================-->

Resource, IDS_DD_ADDR_RUIM_SUPPORTED, Address Book - RUIM
   enum, RUIM Support, IDEL_YESNO
   HELP
      Does the device support an RUIM-based address book?

      (To support an RUIM address book, the device must implement
      AEECLSID_ADDRBOOK_RUIM.)
   }
}

Resource, IDS_DD_MAX_ADDR_COUNT_RUIM, Address Book - RUIM
   uint32, Max Entries
   HELP
      Specify the maximum number of entries in the RUIM address book.  Enter
      0 if there is no limit.
   }
}
Resource, IDS_DD_ADDR_CAT_30_RUIM, Address Book - RUIM
   complex, Categories, 1, 0, 0, |
      enum, Category ID, IDEL_ADDR_CAT
      string, Category Name
   }
   HELP
      List each category the RUIM address book supports.  Refer to AEEAddrBook.h and
      the BREW API Reference for more information.
      
      Category ID - Enter the unique AEEAddrCat value for this category
      in terms of the AEE_ADDR_CAT_xxx macros from AEEAddrBook.h.
      For BREW 2.1, OEM-defined categories begin at
      AEE_ADDR_CAT_USER_DEFINED.  For BREW 3.0 and later, OEM-defined
      categories begin at AEE_ADDR_CAT_USER (AEE_ADDR_CAT_USER_DEFINED
      has been deprecated in BREW 3.0).  If the device does not support
      categories, enter AEE_ADDR_CAT_NONE.
      
      Category Name - Enter the text name of this category.  For example:
      Business, Personal, Friends, etc.  If the device does not support
      categories, enter "None".
   }
}
Resource, IDS_DD_ADDR_FIELDS_30_RUIM, Address Book - RUIM
   complex, Fields, 1, 0, 0, |
      enum, Category, IDEL_ADDR_CAT
      enum, Field ID, IDEL_ADDR_FIELD
      string, Field Name
      uint32, Max Items
      enum, Field Type, IDEL_ADDR_FIELD_TYPE
      enum, Field Search, IDEL_LABEL_YESNO
      enum, Category Search, IDEL_LABEL_YESNO
      enum, Required, IDEL_LABEL_YESNO
      uint32, Max Length
   }
   HELP
      List each field the RUIM address book supports, and specify the characteristics
      of each field.  Refer to AEEAddrBook.h and the BREW API Reference
      for more information on the AEEAddrFieldInfo data structure.

      IMPORTANT:  List all fields available in all categories with a category
      of AEE_ADDR_CAT_NONE.
   
      Category - Enter the category this field is available in.  Most
      fields are available in all categories -- these fields must be
      listed once for each category they are available in.
      
      Field Name - Enter the text name of the field.  For example, "Name", 
      "email", "Work Phone", etc.

      Field ID - Enter the AEEAddrFieldID for this field.  Predefined field
      IDs are at the beginning of the list.  OEM-defined values are at the end
      of the list.  For BREW 2.1, the OEM-defined values begin at
      AEE_ADDRFIELD_USER_DEFINED.  For BREW 3.0 and later, the OEM-defined
      values begin at AEE_ADDRFIELD_USER (AEE_ADDRFIELD_USER_DEFINED is
      deprecated).  AEE_ADDR_FIELD_xxx values are defined in AEEAddrBook.h.
      You may need technical assistance from the developer of OEMAddrBook.c
      to determine these values.

      Field Type - Enter the AEEAddrFieldType for this field.

      Max Items - Enter the maximum allowed number of items of this fieldID
      in each record.  For example, if fieldID is AEE_ADDRFIELD_EMAIL, then 
      maxItems could be 2 if OEM address book supports only a maximum of 2 
      email entries per record.

      Field Search - Can a search (EnumRec) be done based on this field?  That
      is, can we make a call to IADDRBOOK_EnumRecInit() to search for all
      records having a specific value for this given field ID.

      Category Search - Can a search (EnumRec) be done based on this field
      within a category?  That is, can we use IADDRBOOK_EnumRecInit() to
      search for all records of a specific category having a specific value for
      this field?

      Required - Is this field required to be present in all records?

      Max Length - Enter the maximum length of this field in units of the
      AEEAddrFieldType.  For example, if this is a string field that can hold
      a maximum of 50 AECHARs, enter 50, not 100 bytes.
   }
}
Resource, IDS_DD_ADDR_USER_DEF_CAT_RUIM, Address Book - RUIM
   enum, App Category Definition, IDEL_YESNO
   HELP
      Can a BREW application create a record in the RUIM-based address book
      with an AEEAddrCat that is not one of the categories returned by
      IADDRBOOK_EnumNextCategory()?  Select
      Yes if applications may create records with their own unique 
      categories.  Select No if applications are restricted to the categories
      defined by the OEM.
   }
}
Resource, IDS_DD_ADDR_USER_DEF_FIELD_RUIM, Address Book - RUIM
   enum, App Field Definition, IDEL_YESNO
   HELP
      Can a BREW application create an address book field in the RUIM-based
      address book with an AEEAddrFieldID
      that is not one of the field IDs returned by 
      IADDRBOOK_EnumNextFieldsInfo()?  Enter Yes if applications may create 
      their own field IDs.  Enter No if applications are restricted to the field
      IDs defined by the OEM.
   }
}
Resource, IDS_DD_ADDR_REMOVE_ALL_SUPPORTED_RUIM, Address Book - RUIM
   enum, RemoveAllRecs Support, IDEL_YESNO
   HELP
      Does the RUIM-based address book support the IADDRBOOK_RemoveAllRecs() method?
   }
}
#<!--=================================================================
#        Camera
#=================================================================-->
Resource, IDS_DD_CAMERA_SUPP, Camera Services
   enum, Camera Support, IDEL_LABEL_YESNO
   HELP
      Is the ICamera interface implemented on this handset?
   }
}
Resource, IDS_DD_CAMERA_RES, Camera Services
   string, Resolution
   HELP
      Enter the resolution in pixels.
   }
}
Resource, IDS_DD_CAMERA_MIME_TYPES, Camera Services
   string, Camera MIME Types, , |
   HELP
      Enter a comma separated list of all applicable MIME types for Camera 
			services available to BREW - e.g., image/jpg
   }
}
Resource, IDS_DD_CAMERA_FORMATS, Camera Services
   string, Camera Formats, , |
   HELP
      Enter a comma separated list of supported Camera formats.  For
      example, "bmp, png".
   }
}
Resource, IDS_DD_CAMERA_MCF, Camera Services, MCF Directories
   enum, Pictures, IDEL_LABEL_YESNO
	 enum, Music, IDEL_LABEL_YESNO
	 enum, Movie, IDEL_LABEL_YESNO
	 enum, Theme, IDEL_LABEL_YESNO
	 enum, Text, IDEL_LABEL_YESNO
	 enum, Sound, IDEL_LABEL_YESNO
	 HELP
	    Select all the possible MCF directories where Camera files can be stored
   }
}
Resource, IDS_DD_CAMERA_RESTRICTIONS, Camera Services
   string, Restrictions
	 HELP
	    List any restrictions associated with the file types in this category - size, 
			bit map depth, number of files, etc
   }
}
Resource, IDS_DD_CAMERA_DELETE, Camera Services
   enum, Delete Camera files from Native UI, IDEL_LABEL_YESNO
	 HELP
	    Is it possible from the native user interface to delete Camera images in the MCF directories?
   }
}

#<!--=================================================================
#        Image And Other Media Interaction
#=================================================================-->
Resource, IDS_DD_MEDIA_WALLPAPER_MIME_TYPES, Wallpaper Services
   string, Wallpaper MIME Types, , |
   HELP
      Enter a comma separated list of all applicable MIME types for Wallpaper 
			services available to BREW - e.g., image/jpg
   }
}
Resource, IDS_DD_MEDIA_WALLPAPER_FORMATS, Wallpaper Services
   string, Wallpaper Formats, , |
   HELP
      Enter a comma separated list of supported wallpaper formats.  For
      example, "bmp, png".
   }
}
Resource, IDS_DD_MEDIA_WALLPAPER_MCF, Wallpaper Services, MCF Directories
   enum, Pictures, IDEL_LABEL_YESNO
	 enum, Music, IDEL_LABEL_YESNO
	 enum, Movie, IDEL_LABEL_YESNO
	 enum, Theme, IDEL_LABEL_YESNO
	 enum, Text, IDEL_LABEL_YESNO
	 enum, Sound, IDEL_LABEL_YESNO
	 HELP
	    Select all the possible MCF directories where wallpaper files can be stored
   }
}
Resource, IDS_DD_MEDIA_WALLPAPER_RESTRICTIONS, Wallpaper Services,
   string, Restrictions
	 HELP
	    List any restrictions associated with the file types in this category - size, 
			bit map depth, number of files, etc
   }
}
Resource, IDS_DD_MEDIA_WALLPAPER_DELETE, Wallpaper Services
   enum, Delete Wallpaper files from Native UI, IDEL_LABEL_YESNO
	 HELP
	    Is it possible from the native user interface to delete wallpaper images in the MCF directories?
   }
}
Resource, IDS_DD_MEDIA_WALLPAPER_IMG_X, Wallpaper Services
   uint32, Wallpaper Size X, 
   HELP
      Enter the recommended width of images used for wallpaper.  Document
      any minimum or maximum width limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_WALLPAPER_IMG_Y, Wallpaper Services
   uint32, Wallpaper Size Y
   HELP
      Enter the recommended height of images used for wallpaper.  Document
      any minimum or maximum height limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_CALLER_ID_MIME_TYPES, Caller ID Services
   string, CallerID MIME Type
   HELP
      List all applicable MIME types for Caller ID services available to BREW - e.g. image/bmp
   }
}
Resource, IDS_DD_MEDIA_CALLER_ID_FORMATS, Caller ID Services
   string, CallerID Formats, , |
   HELP
      Enter a comma separated list of supported image formats for CallerID.
			For example, "bmp, png".
   }
}
Resource, IDS_DD_MEDIA_CALLER_ID_MCF, Caller ID Services, MCF Directories
   enum, Pictures, IDEL_LABEL_YESNO
	 enum, Music, IDEL_LABEL_YESNO
	 enum, Movie, IDEL_LABEL_YESNO
	 enum, Theme, IDEL_LABEL_YESNO
	 enum, Text, IDEL_LABEL_YESNO
	 enum, Sound, IDEL_LABEL_YESNO
	 HELP
	    Select all the possible MCF directories where Caller ID files can be stored
   }
}
Resource, IDS_DD_MEDIA_CALLER_ID_RESTRICTIONS, Caller ID Services,
   string, Restrictions
	 HELP
	    List any restrictions associated with the file types in this category - size, 
			bit map depth, number of files, etc
   }
}
Resource, IDS_DD_MEDIA_CALLER_ID_DELETE, Caller ID Services
   enum, Delete Caller ID files from Native UI, IDEL_LABEL_YESNO
	 HELP
	    Is it possible from the native user interface to delete Caller ID images in the MCF directories?
   }
}
Resource, IDS_DD_MEDIA_CALLER_ID_IMG_X, Caller ID Services
   uint32, CallerID Image Size X
   HELP
      Enter the recommended width of images used for CallerID images.  Document
      any minimum or maximum width limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_CALLER_ID_IMG_Y, Caller ID Services
   uint32, CallerID Image Size Y
   HELP
      Enter the recommended height of images used for CallerID images.  Document
      any minimum or maximum height limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_SSAVER_MIME_TYPES, Native Screen Saver Services
   string, Screen Saver MIME Types, , |
   HELP
      List all applicable MIME types for Native screen savers that are available to BREW  - e.g. image/png
   }
}
Resource, IDS_DD_MEDIA_SSAVER_FORMATS, Native Screen Saver Services
   string, ScreenSaver Formats, , |
   HELP
      Enter a comma separated list of supported screen saver formats.  For
      example, "bmp, png, pmd".
   }
}
Resource, IDS_DD_MEDIA_SSAVER_MCF, Native Screen Saver Services, MCF Directories
   enum, Pictures, IDEL_LABEL_YESNO
	 enum, Music, IDEL_LABEL_YESNO
	 enum, Movie, IDEL_LABEL_YESNO
	 enum, Theme, IDEL_LABEL_YESNO
	 enum, Text, IDEL_LABEL_YESNO
	 enum, Sound, IDEL_LABEL_YESNO
	 HELP
	    Select all the possible MCF directories where Native Screen Saver files can be stored
   }
}
Resource, IDS_DD_MEDIA_SSAVER_RESTRICTIONS, Native Screen Saver Services,
   string, Restrictions
	 HELP
	    List any restrictions associated with the file types in this category - size, 
			bit map depth, number of files, etc
   }
}
Resource, IDS_DD_MEDIA_SSAVER_DELETE, Native Screen Saver Services
   enum, Delete Native Screen Saver files from Native UI, IDEL_LABEL_YESNO
	 HELP
	    Is it possible from the native user interface to delete Native Screen Saver images in the MCF directories?
   }
}
Resource, IDS_DD_MEDIA_SSAVER_IMG_X, Native Screen Saver Services
   uint32, ScreenSaver Size X
   HELP
      Enter the recommended width of images used for screen saver images.  Document
      any minimum or maximum width limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_SSAVER_IMG_Y, Native Screen Saver Services
   uint32, ScreenSaver Size Y
   HELP
      Enter the recommended height of images used for screen saver images.  Document
      any minimum or maximum height limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_POWERONOFF_MIME_TYPES, Power ON/OFF Services
   string, Power On/Off MIME Types
   HELP
      Is it possible to set images in the shared directory for Power On/Off purposes?
   }
}
Resource, IDS_DD_MEDIA_POWERONOFF_FORMATS, Power ON/OFF Services
   string, Power On/Off Formats, , |
   HELP
      Enter a comma separated list of supported Power On/Off formats.  For
      example, "bmp, png, pmd".
   }
}
Resource, IDS_DD_MEDIA_POWERONOFF_MCF, Power ON/OFF Services, MCF Directories
   enum, Pictures, IDEL_LABEL_YESNO
	 enum, Music, IDEL_LABEL_YESNO
	 enum, Movie, IDEL_LABEL_YESNO
	 enum, Theme, IDEL_LABEL_YESNO
	 enum, Text, IDEL_LABEL_YESNO
	 enum, Sound, IDEL_LABEL_YESNO
	 HELP
	    Select all the possible MCF directories where Power ON/OFF files can be stored
   }
}
Resource, IDS_DD_MEDIA_POWERONOFF_RESTRICTIONS, Power ON/OFF Services,
   string, Restrictions
	 HELP
	    List any restrictions associated with the file types in this category - size, 
			bit map depth, number of files, etc
   }
}
Resource, IDS_DD_MEDIA_POWERONOFF_DELETE, Power ON/OFF Services
   enum, Delete Power ON/OFF files from Native UI, IDEL_LABEL_YESNO
	 HELP
	    Is it possible from the native user interface to delete Power ON/OFF images in the MCF directories?
   }
}
Resource, IDS_DD_MEDIA_POWERONOFF_IMG_X, Power ON/OFF Services
   uint32, Power On/Off Size X
   HELP
      Enter the recommended width of images used for Power On/Off images.  Document
      any minimum or maximum width limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_POWERONOFF_IMG_Y, Power ON/OFF Services
   uint32, Power On/Off Size Y
   HELP
      Enter the recommended height of images used for Power On/Off images.  Document
      any minimum or maximum height limitations in the Comment field.
   }
}
Resource, IDS_DD_MEDIA_AUDIO_MIME_TYPES, Audio Services
   string, Audio MIME Types
   HELP
	    List all applicable MIME types for Audio services available to BREW - e.g. audio/mp3
   }
}
Resource, IDS_DD_MEDIA_AUDIO_FORMATS, Audio Services
   string, Audio Formats, , |
   HELP
      Enter a comma separated list of supported Audio formats.  For
      example, "mid, aac, mp3".
   }
}
Resource, IDS_DD_MEDIA_AUDIO_MCF, Audio Services, MCF Directories
   enum, Pictures, IDEL_LABEL_YESNO
	 enum, Music, IDEL_LABEL_YESNO
	 enum, Movie, IDEL_LABEL_YESNO
	 enum, Theme, IDEL_LABEL_YESNO
	 enum, Text, IDEL_LABEL_YESNO
	 enum, Sound, IDEL_LABEL_YESNO
	 HELP
	    Select all the possible MCF directories where Audio files can be stored
   }
}
Resource, IDS_DD_MEDIA_AUDIO_RESTRICTIONS, Audio Services,
   string, Restrictions
	 HELP
	    List any restrictions associated with the file types in this category - size, 
			number of files, etc
   }
}
Resource, IDS_DD_MEDIA_AUDIO_DELETE, Audio Services
   enum, Delete Audio files from Native UI, IDEL_LABEL_YESNO
	 HELP
	    Is it possible from the native user interface to delete Audio images in the MCF directories?
   }
}

#<!--=================================================================
#       BREW Screen Saver
#=================================================================-->
EnumList, IDEL_SSAVER_TYPE
   BREW Only, BREW Only
   Native Only, Native Only
   BREW and Native, BREW and Native
}
EnumList, IDEL_SSAVER_BACKLIGHT
   BREW, BREW
   Native UI, Native UI
   N/A, N/A
}
Resource, IDS_DD_SSAVER_TYPE, BREW Screen Saver
   enum, Screen Saver Type, IDEL_SSAVER_TYPE
   HELP
      Does the device support a BREW-only, Native UI-only, or both BREW
      and Native UI screen savers?
   }
}
Resource, IDS_DD_SSAVER_TIMER, BREW Screen Saver
   uint32, Timer
   HELP
      After what period of inactivity will the Screen Saver be activated?
   }
}

#<!--=================================================================
#        Call History
#=================================================================-->

EnumList, IDEL_CALL_HISTORY_FIELDS
   none, None
   1, AEECALLHISTORY_FIELD_CALL_TYPE
   2, AEECALLHISTORY_FIELD_NUMBER_TYPE
   3, AEECALLHISTORY_FIELD_NUMBER_PLAN
   4, AEECALLHISTORY_FIELD_DATE_TIME
   5, AEECALLHISTORY_FIELD_CALL_DURATION
   6, AEECALLHISTORY_FIELD_NUMBER
   7, AEECALLHISTORY_FIELD_NAME
   8, AEECALLHISTORY_FIELD_HANDLER_CLSID
   9, AEECALLHISTORY_FIELD_NUMBER_EX
}

EnumList, IDEL_CALL_HISTORY_CALL_TYPES
   none, None
   1, AEECALLHISTORY_CALL_TYPE_TO
   2, AEECALLHISTORY_CALL_TYPE_FROM
   3, AEECALLHISTORY_CALL_TYPE_MISSED
}

EnumList, IDEL_CALL_HISTORY_NUMBER_TYPES
   none, None
   1, AEECALLHISTORY_NUMBER_TYPE_INTERNATIONAL
   2, AEECALLHISTORY_NUMBER_TYPE_NATIONAL
   3, AEECALLHISTORY_NUMBER_TYPE_NETWORK
   4, AEECALLHISTORY_NUMBER_TYPE_SUBSCRIBER
   5, AEECALLHISTORY_NUMBER_TYPE_ABBREVIATED
   6, AEECALLHISTORY_NUMBER_TYPE_QCHAT
}

EnumList, IDEL_CALL_HISTORY_PLAN_TYPES
   none, None
   1, AEECALLHISTORY_NUMBER_PLAN_TELEPHONY
   2, AEECALLHISTORY_NUMBER_PLAN_DATA
   3, AEECALLHISTORY_NUMBER_PLAN_TELEX
   4, AEECALLHISTORY_NUMBER_PLAN_PRIVATE
}

Resource, IDS_DD_CH_SORTED_BY_TYPE, Call History
   enum, Sorted By Type, IDEL_YESNO
   HELP
      Are call history records sorted into incoming, outgoing, and/or
      missed categories?.
   }
}
Resource, IDS_DD_CH_MAX_ENTRIES, Call History
   uint32, Max Entries
   HELP
      Enter the maximum number of entries stored in call history.  If entries
      are sorted by type, this is the maximum number of entries per type.
   }
}
Resource, IDS_DD_CH_REQUIRED_FIELDS, Call History
   complex, Required Fields, 0, , ,
      enum, Field ID, IDEL_CALL_HISTORY_FIELDS
   }
   HELP
      List any fields that must be present in a call history entry.
   }
}
Resource, IDS_DD_CH_UNSUPPORTED_FIELDS, Call History
   complex, Unsupported Fields, 0, , ,
      enum, Field ID, IDEL_CALL_HISTORY_FIELDS
   }
   HELP
      List any fields that are not stored by device's call history
      implementation.
   }
}
Resource, IDS_DD_CH_ADDITIONAL_FIELDS, Call History
   complex, Additional Fields, 0, , ,
      enum, Field ID, IDEL_CALL_HISTORY_FIELDS
   }
   HELP
      List any fields that the device adds to a call history entry
      in addition to those fields passed to ICALLHISTORY_AddEntry().  For
      example, if ICallHistory automatically adds a timestamp field
      to each entry.
   }
}
Resource, IDS_DD_CH_SUPPORTS_USRDEF_FIELDS, Call History
   enum, User Fields, IDEL_YESNO
   HELP
      Are user-defined field types supported?
   }
}
Resource, IDS_DD_CH_UPDATE_ENTRY_SUPPORTED, Call History
   enum, UpdateEntry Supported, IDEL_YESNO
   HELP
      Are Call History Entries allowed to be modified?
   }
}
Resource, IDS_DD_CH_NOTIFY_SUPPORTED, Call History
   enum, Notify Supported, IDEL_YESNO
   HELP
      Does the OEM support Notify functionality?  
   }
}
Resource, IDS_DD_CH_UNSUPPORTED_CALL_TYPES, Call History
   complex, Unsupported Call Types, 0, , ,
      enum, Field ID, IDEL_CALL_HISTORY_CALL_TYPES
   }
   HELP
      List any call types that are not supported.
   }
}
Resource, IDS_DD_CH_UNSUPPORTED_NUMBER_TYPES, Call History
   complex, Unsupported Number Types, 0, , ,
      enum, Field ID, IDEL_CALL_HISTORY_NUMBER_TYPES
   }
   HELP
      List any number types that are not supported.
   }
}
Resource, IDS_DD_CH_UNSUPPORTED_NUMBER_PLANS, Call History
   complex, Unsupported Plan Types, 0, , ,
      enum, Field ID, IDEL_CALL_HISTORY_PLAN_TYPES
   }
   HELP
      List any plan types that are not supported.
   }
}
Resource, IDS_DD_CH_DUP_PHONE_NUMS_ALLOWED, Call History
   enum, Duplicate Entries Allowed, IDEL_YESNO
   HELP
      Are duplicate call history entries allowed?
   }
}

#<!--=================================================================
#        Additional Socket Parameters
#        ID Range: 280..299
#=================================================================-->
Resource, IDS_DATA_SERVER_SOCKETS, Network/Socket Specification
   enum, Server Sockets, IDEL_LABEL_YESNO
   HELP
      Does the device support server sockets?

      Server socket support means that ISOCKET_Listen() and 
      ISOCKET_Accept() are supported.
   }
}
Resource, IDS_DATA_SHUTDOWN, Network/Socket Specification
   enum, Shutdown, IDEL_LABEL_YESNO
   HELP
      Does the device support TCP socket shutdown (ISOCKET_Shutdown())?
   }
}
Resource, IDS_DATA_LOOPBACK, Network/Socket Specification
   enum, Loopback, IDEL_LABEL_YESNO
   HELP
      Does the device support a loopback interface (for example,
      127.0.0.1)?
   }
}
Resource, IDS_DATA_UDP_PAYLOAD_MAX, Network/Socket Specification
   uint32, Max UDP Payload
   HELP
      Enter the maximum payload size (in bytes) for UDP datagrams
      sent via ISocket.
   }
}

#<!--=================================================================
#        MIF Image Info
#        ID Range: 300..319
#=================================================================-->
Resource, IDS_MIF_IMAGE_SMALL_X, MIF Information
   uint32, MIF Small Image Width
   HELP
      Enter the maximum width (x) of the Small Image in a MIF file.

      This is typically the APP_THUMB_X_THRESHOLD value from
      AppMgrSettings.h.  This is the image size used by AppMgr for all images
      in List View and the bottom icons in Large Icon View.

      In MIF Editor 2.1, this image is specified in the Thumbnail field in the
      Advanced Applet Information dialog.

      In MIF Editor 3.0, this image is specified on the Applets tab.
   }
}
Resource, IDS_MIF_IMAGE_SMALL_Y, MIF Information
   uint32, MIF Small Image Height
   HELP
      Enter the maximum height (y) of the Small Image in a MIF file.

      This is typically the APP_THUMB_Y_THRESHOLD value from
      AppMgrSettings.h.  This is the image size used by AppMgr for all images
      in List View and the bottom icons in Large Icon View.

      In MIF Editor 2.1, this image is specified in the Thumbnail field in the
      Advanced Applet Information dialog.

      In MIF Editor 3.0, this image is specified on the Applets tab.
   }
}
Resource, IDS_MIF_IMAGE_MEDIUM_X, MIF Information
   uint32, MIF Medium Image Width
   HELP
      Enter the maximum width (x) of the Medium Image in a MIF file.
      This is a medium image .

      This is typically the APP_ICON_X_THRESHOLD value from
      AppMgrSettings.h.  This is the image size used by AppMgr for all images
      in Grid View.

      In MIF Editor 2.1, this image is specified in the Icon field on the
      Applets tab.

      In MIF Editor 3.0, this image is specified on the Applets tab.
   }
}
Resource, IDS_MIF_IMAGE_MEDIUM_Y, MIF Information
   uint32, MIF Medium Image Height
   HELP
      Enter the maximum height (y) of the Medium Image in a MIF file.

      This is typically the APP_ICON_Y_THRESHOLD value from
      AppMgrSettings.h.  This is the image size used by AppMgr for all images
      in Grid View.

      In MIF Editor 2.1, this image is specified in the Icon field on the
      Applets tab.

      In MIF Editor 3.0, this image is specified on the Applets tab.
   }
}
Resource, IDS_MIF_IMAGE_LARGE_X, MIF Information
   uint32, MIF Large Image Width
   HELP
      Enter the maximum width (x) of the Large Image in a MIF file.

      This is typically the APP_IMAGE_X_THRESHOLD value from
      AppMgrSettings.h.  This is the image size used by AppMgr for the large
      centered image in Large Icon View.

      In MIF Editor 2.1, this image is specified in the Image field in the
      Advanced Applet Information dialog.

      In MIF Editor 3.0, this image is specified on the Applets tab.
   }
}
Resource, IDS_MIF_IMAGE_LARGE_Y, MIF Information
   uint32, MIF Large Image Height
   HELP
      Enter the maximum height (y) of the Large Image in a MIF file.

      This is typically the APP_IMAGE_Y_THRESHOLD value from
      AppMgrSettings.h.  This is the image size used by AppMgr for the large
      centered image in Large Icon View.

      In MIF Editor 2.1, this image is specified in the Image field in the
      Advanced Applet Information dialog.

      In MIF Editor 3.0, this image is specified on the Applets tab.
   }
}

#<!--_______________________________________
#                Flips 
#_______________________________________-->
EnumList, IDEL_FLIP_ID
0,Primary Flip (Clamshell)
}
EnumList, IDEL_FLIP_POSITION_TYPE
0,Position is in angles
1,Position is linear
}
EnumList, IDEL_FLIP_PARM
1,FLIP_PARM_IS_SUPPORT
2,FLIP_PARM_DISPLAYLIST
3,FLIP_PARM_KEYLIST
}
EnumList, IDEL_FLIP_CAPABILITIES
1,Flip
2,KeyGuard
16,ScreenRotate

HELP
   This enum list lists the type of device notifier events a flip
   can generate.
}
Resource, IDS_DD_FLIP_INFO, Flip
   uint32,NumFlips,0,255,0
   complex,FlipInfo,1,255,1,|
      enum,FlipID,IDEL_FLIP_ID
      enum,FlipPosType,IDEL_FLIP_POSITION_TYPE
      uint32,FlipCapabilityMask
   }
   HELP
      NumFlips: Number of flips on the device.
      
      FlipID: ID of the flip
      
      FlipPosType: Position type of the flip, see IDEL_FLIP_POSITION_TYPE.
            
      FlipCapabilityMask: OR-ed mask of all flip capabilities.
      Flip capabilities are (also see IDEL_FLIP_CAPABILITIES):
      
      1,Flip
      
      2,KeyGuard
      
      16,ScreenRotate   
   }
}
Resource, IDS_DD_FLIP_POS_MIN_MAX, Flip
   complex,FlipMinMaxPositions,1,0,0,|
      enum,FlipID,IDEL_FLIP_ID
      uint32,Min X
      uint32,Min Y
      uint32,Min Z
      uint32,Max X
      uint32,Max Y
      uint32,Max Z
   } 
   HELP
      Minimum and Maximum positions of each flip on the
      X,Y,Z axes.
   }
}
Resource, IDS_DD_FLIP_COMMON_PARM_LIST, FlipCommonParmList
   complex,ParmSupported
      enum,ParmID,IDEL_FLIP_PARM
   }
   HELP
      Lists the parms that are not specific to a flip.              
   }
}
Resource, IDS_DD_FLIP_1_OPEN_KEY_LIST, Flip_1_OpenKeyList
   enum,FlipID,IDEL_FLIP_ID
   complex,KeysWhenFlipOpen
      enum,KeyCode,IDEL_KEYCODES
   }
   HELP
      Lists the key codes of keys accessible on the device when a 
      specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      IDS_DD_FLIP_1_OPEN_KEY_LIST, IDS_DD_FLIP_2_OPEN_KEY_LIST, IDS_DD_FLIP_3_OPEN_KEY_LIST,
      IDS_DD_FLIP_4_OPEN_KEY_LIST, IDS_DD_FLIP_5_OPEN_KEY_LIST
   }
}
Resource, IDS_DD_FLIP_2_OPEN_KEY_LIST, Flip_2_OpenKeyList
   enum,FlipID,IDEL_FLIP_ID
   complex,KeysWhenFlipOpen
      enum,KeyCode,IDEL_KEYCODES
   }
   HELP
      Lists the key codes of keys accessible on the device when a 
      specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      IDS_DD_FLIP_1_OPEN_KEY_LIST, IDS_DD_FLIP_2_OPEN_KEY_LIST, IDS_DD_FLIP_3_OPEN_KEY_LIST,
      IDS_DD_FLIP_4_OPEN_KEY_LIST, IDS_DD_FLIP_5_OPEN_KEY_LIST
   }
}
Resource, IDS_DD_FLIP_3_OPEN_KEY_LIST, Flip_3_OpenKeyList
   enum,FlipID,IDEL_FLIP_ID
   complex,KeysWhenFlipOpen
      enum,KeyCode,IDEL_KEYCODES
   }
   HELP
      Lists the key codes of keys accessible on the device when a 
      specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      IDS_DD_FLIP_1_OPEN_KEY_LIST, IDS_DD_FLIP_2_OPEN_KEY_LIST, IDS_DD_FLIP_3_OPEN_KEY_LIST,
      IDS_DD_FLIP_4_OPEN_KEY_LIST, IDS_DD_FLIP_5_OPEN_KEY_LIST
   }
}
Resource, IDS_DD_FLIP_4_OPEN_KEY_LIST, Flip_4_OpenKeyList
   enum,FlipID,IDEL_FLIP_ID
   complex,KeysWhenFlipOpen
      enum,KeyCode,IDEL_KEYCODES
   }
   HELP
      Lists the key codes of keys accessible on the device when a 
      specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      IDS_DD_FLIP_1_OPEN_KEY_LIST, IDS_DD_FLIP_2_OPEN_KEY_LIST, IDS_DD_FLIP_3_OPEN_KEY_LIST,
      IDS_DD_FLIP_4_OPEN_KEY_LIST, IDS_DD_FLIP_5_OPEN_KEY_LIST
   }
}
Resource, IDS_DD_FLIP_5_OPEN_KEY_LIST, Flip_5_OpenKeyList
   enum,FlipID,IDEL_FLIP_ID
   complex,KeysWhenFlipOpen
      enum,KeyCode,IDEL_KEYCODES
   }
   HELP
      Lists the key codes of keys accessible on the device when a 
      specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      IDS_DD_FLIP_1_OPEN_KEY_LIST, IDS_DD_FLIP_2_OPEN_KEY_LIST, IDS_DD_FLIP_3_OPEN_KEY_LIST,
      IDS_DD_FLIP_4_OPEN_KEY_LIST, IDS_DD_FLIP_5_OPEN_KEY_LIST
   }
}
Resource, IDS_DD_FLIP_CLOSED_KEY_LIST, FlipClosedKeyList
   complex,KeysWhenAllFlipsClosed
      enum,KeyCode,IDEL_KEYCODES
   }
   HELP
      Lists the key codes of keys accessible on the device when
      all flips are fully closed.
   }
}
Resource, IDS_DD_FLIP_1_OPEN_DISPLAY_LIST, Flip_1_OpenDisplayList
   enum,FlipID,IDEL_FLIP_ID
   complex,DisplaysWhenFlipOpen
      enum,ClassID,IDEL_DISPLAY_CLSID
   }
   HELP
      Lists the display class IDs of displays accessible on the device when 
      a specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      
      IDS_DD_FLIP_1_OPEN_DISPLAY_LIST, IDS_DD_FLIP_2_OPEN_DISPLAY_LIST, IDS_DD_FLIP_3_OPEN_DISPLAY_LIST,
      IDS_DD_FLIP_4_OPEN_DISPLAY_LIST, IDS_DD_FLIP_5_OPEN_DISPLAY_LIST 
   }
}
Resource, IDS_DD_FLIP_2_OPEN_DISPLAY_LIST, Flip_2_OpenDisplayList
   enum,FlipID,IDEL_FLIP_ID
   complex,DisplaysWhenFlipOpen
      enum,ClassID,IDEL_DISPLAY_CLSID
   }
   HELP
      Lists the display class IDs of displays accessible on the device when 
      a specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      
      IDS_DD_FLIP_1_OPEN_DISPLAY_LIST, IDS_DD_FLIP_2_OPEN_DISPLAY_LIST, IDS_DD_FLIP_3_OPEN_DISPLAY_LIST,
      IDS_DD_FLIP_4_OPEN_DISPLAY_LIST, IDS_DD_FLIP_5_OPEN_DISPLAY_LIST 
   }
}
Resource, IDS_DD_FLIP_OPEN_3_DISPLAY_LIST, Flip_3_OpenDisplayList
   enum,FlipID,IDEL_FLIP_ID
   complex,DisplaysWhenFlipOpen
      enum,ClassID,IDEL_DISPLAY_CLSID
   }
   HELP
      Lists the display class IDs of displays accessible on the device when 
      a specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      
      IDS_DD_FLIP_1_OPEN_DISPLAY_LIST, IDS_DD_FLIP_2_OPEN_DISPLAY_LIST, IDS_DD_FLIP_3_OPEN_DISPLAY_LIST,
      IDS_DD_FLIP_4_OPEN_DISPLAY_LIST, IDS_DD_FLIP_5_OPEN_DISPLAY_LIST 
   }
}
Resource, IDS_DD_FLIP_4_OPEN_DISPLAY_LIST, Flip_4_OpenDisplayList
   enum,FlipID,IDEL_FLIP_ID
   complex,DisplaysWhenFlipOpen
      enum,ClassID,IDEL_DISPLAY_CLSID
   }
   HELP
      Lists the display class IDs of displays accessible on the device when 
      a specific flip is fully open and all other flips are closed. 
      
      For different flips, use one of the following resources :
      
      IDS_DD_FLIP_1_OPEN_DISPLAY_LIST, IDS_DD_FLIP_2_OPEN_DISPLAY_LIST, IDS_DD_FLIP_3_OPEN_DISPLAY_LIST,
      IDS_DD_FLIP_4_OPEN_DISPLAY_LIST, IDS_DD_FLIP_5_OPEN_DISPLAY_LIST 
   }
}
Resource, IDS_DD_FLIP_5_OPEN_DISPLAY_LIST, Flip_5_OpenDisplayList
   enum,FlipID,IDEL_FLIP_ID
   complex,DisplaysWhenFlipOpen
      enum,ClassID,IDEL_DISPLAY_CLSID
   }
   HELP
      Lists the display class IDs of displays accessible on the device when 
      a specific flip is fully open and all other flips are closed.
      
      For different flips, use one of the following resources :
      
      IDS_DD_FLIP_1_OPEN_DISPLAY_LIST, IDS_DD_FLIP_2_OPEN_DISPLAY_LIST, IDS_DD_FLIP_3_OPEN_DISPLAY_LIST,
      IDS_DD_FLIP_4_OPEN_DISPLAY_LIST, IDS_DD_FLIP_5_OPEN_DISPLAY_LIST 
   }
}
Resource, IDS_DD_FLIP_CLOSED_DISPLAY_LIST, FlipClosedDisplayList
   complex,DisplaysWhenAllFlipClosed
      enum,ClassID,IDEL_DISPLAY_CLSID
   }
   HELP
      Lists the display class IDs of displays accessible on the device when 
      all flips are fully closed.
   }
}



#<!--=================================================================
#         Auto-start App Configuration
#=================================================================-->
Resource, IDS_DD_APP_AUTOSTART, Auto-start App
   string, Auto-start App's ID
   HELP
      Enter the CLSID of the auto-start app as a hexadecimal number preceeded by 0x. For example: 
      0x12345678. The default is 0x1008000, which is the CLSID of AppManager (AEECLSID_APPMANAGER).
      
      NOTE:  This is the value returned by OEM_GetConfig() for item CFGI_AUTOSTART.
   }
}
Resource, IDS_DD_APP_AUTOSTARTARGS, Auto-start App
   string, Arguments to Auto-start App
   HELP
      Enter the arguments to be passed to the auto-start app.
      
      NOTE:  This is the value returned by OEM_GetConfig() for item CFGI_AUTOSTARTARGS.
   }
}


#<!--=================================================================
#        Class ID Configuration
#=================================================================-->
Resource, IDS_CLSID_FIRST, Obsolete
   uint32, CLSID Start ID
}
Resource, IDS_CLSID_MAX, Obsolete
   uint32, No. of CLSIDs
}

#<!--_______________________________________
#                Class IDs
#      ID Range: 8201+
#      IDS_CLSID_LAST: 8999  
#_______________________________________-->
EnumList, IDEL_CLSID
None, None
16798977, MIDI
16798978, MP3
16798979, QCP
16798980, PMD
16798982, MIDIOutQCP
16798983, MPEG4
16798984, MMF
16798985, PHRASE
16798986, IMA-ADPCM
16798987, AAC
16798988, IMelody
16798990, AMR
16798993, PCM
16798994, XMF
16798995, DLS
16798996, SVG
16793601, BMP
16793603, GIF
16793604, PNG
16793605, JPEG
16793606, BCI
16785427, Camera
16785418, Vocoder
16959124, Camera2
16959125, Camera3
16959126, Camera4
16915499, Joystick
0, Last
}
EnumList, IDEL_MEDIA_FEATURE
0,None
4,Volume          
5,Mute            
6,Tempo           
7,Tune            
8,Pan             
65536,PauseResume     
65537,Seek            
65538,GetTotalTime    
65539,Record          
65540,RecPauseResume  
65541,StreamingPlay
65542,ChannelShare
65543,AudioPostcard
}
#<!--_______________________________________
#                Vocoders Supported
#      IS96   : QCELP-8k
#      IS96A  : QCELP-8k
#      IS733  : QCELP-13k
#      IS127  : EVRC-8k
#      SMV    : SMV for QChat Demo
#      PCM    : PCM     
#      AMR    : AMR
#      G711   : G.711
#      4GV_NB : 4GV Narrowband
#_______________________________________-->
EnumList, IDEL_VOCODERS_SUPPORTED
0,None
1,IS96
2,IS96A
3,IS733
4,IS127
5,SMV
6,PCM
7,AMR
8,G711
9,VOC_4GV_NB
}
Resource, IDS_AEECLSID_MEDIAMIDI, MIDI Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, MIDI Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_MIDI_MIME_TYPES, MIDI Configuration
   string, MIDI MIME Types, , |
   HELP
      Enter a comma separated list of all the MIDI MIME Types supported on the device
   }
}
Resource, IDS_DD_AUD_MIDI_NUM_VOICES, MIDI Configuration
   uint32, Number of tones
   HELP
      Number of MIDI - Polyphonic tones supported by the device
   }
}   
Resource, IDS_AEECLSID_MEDIAMP3, MP3 Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_MP3_MIME_TYPES, MP3 Configuration
   string, MP3 MIME Types, , |
   HELP
      Enter a comma separated list of all the MP3 MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_MEDIAQCP, QCP Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_QCP_MIME_TYPES, QCP Configuration
   string, QCP MIME Types, , |
   HELP
      Enter a comma separated list of all the QCP MIME Types supported on the device
   }
}
Resource, IDS_DD_AUD_QCELP_PLAY, QCP Configuration
   enum, QCELP Play, IDEL_LABEL_YESNO
   HELP
      Is QCELP playback supported on this device?
   }
}
Resource, IDS_DD_AUD_QCELP_RECORD, QCP Configuration
   enum, QCELP Record, IDEL_LABEL_YESNO
   HELP
      Is QCELP recording supported on this device?
   }
}
Resource, IDS_DD_AUD_QCELP_RINGER, QCP Configuration
   enum, QCELP Ringer, IDEL_LABEL_YESNO
   HELP
      Are QCELP ringers supported on this device?
   }
}
Resource, IDS_AEECLSID_MEDIAPMD, PMD Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_MMEDIA_PMD_MIME_TYPES, PMD Configuration
   string, PMD MIME Types, , |
   HELP
      Enter a comma separated list of all the PMD MIME Types supported on the device
   }
}
Resource, IDS_DD_MMEDIA_PMD, PMD Configuration
   enum, CMX, IDEL_LABEL_YESNO
   HELP
      Is the CMX (.pmd) Multimedia File Format (Compact MIDI, SAF, PNG, JPEG,
      QCELP, ADPCM) supported on this device? If so enter the CMX version
			supported by the device in the Comments. Enter any types not supported
			in the Comments
			
      
      Note: CMX needs to be supported through BREW and the handset's native
      UI.  CMX files must be playable as ringers, wallpapers, and screensavers.
   }
}
Resource, IDS_AEECLSID_MEDIAMIDIOUTQCP, MIDIOUTQCP Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_AEECLSID_MPEG4, MPEG4 Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_MMEDIA_MPEG4_MIME_TYPES, MPEG4 Configuration
   string, MPEG4 MIME Types, , |
   HELP
      Enter a comma separated list of all the MPEG4 MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_MEDIAMMF, MMF/SMAF Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_MMF_MIME_TYPES, MMF/SMAF Configuration
   string, MMF MIME Types, , |
   HELP
      Enter a comma separated list of all the MMF MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_MEDIAPHR, PHRASE Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_PHRASE_MIME_TYPES, PHRASE Configuration
   string, PHRASE MIME Types, , |
   HELP
      Enter a comma separated list of all the PHRASE MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_MEDIAADPCM, ADPCM Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_ADPCM_MIME_TYPES, ADPCM Configuration
   string, ADPCM MIME Types, , |
   HELP
      Enter a comma separated list of all the ADPCM MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_MEDIAIMELODY, IMELODY Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_IMELODY_MIME_TYPES, IMELODY Configuration
   string, IMELODY MIME Types, , |
   HELP
      Enter a comma separated list of all the IMELODY MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_MEDIAAMR, AMR Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_AMR_MIME_TYPES, AMR Configuration
   string, AMR MIME Types, , |
   HELP
      Enter a comma separated list of all the AMR MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_MEDIAAAC, AAC Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_AAC_MIME_TYPES, AAC Configuration
   string, AAC MIME Types, , |
   HELP
      Enter a comma separated list of all the AAC MIME Types supported on the device
   }
}
Resource, IDS_DD_AUD_AAC_PLUS, AAC Configuration
   enum, AAC+, IDEL_LABEL_YESNO
	 HELP
	    Is the AAC+ format supported on this device?
   }
}
Resource, IDS_AEECLSID_BMP, BMP Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      IImage-based class ID configuration.
   }
}
Resource, IDS_DD_IMG_BMP_MIME_TYPES, BMP Configuration
   string, BMP MIME Types, , |
   HELP
      Enter a comma separated list of all the BMP MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_GIF, GIF Class ID Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      IImage-based class ID configuration.
   }
}
Resource, IDS_AEECLSID_PNG, PNG Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      IImage-based class ID configuration.
   }
}
Resource, IDS_DD_IMG_PNG_MIME_TYPES, PNG Configuration
   string, PNG MIME Types, , |
   HELP
      Enter a comma separated list of all the PNG MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_JPEG, JPEG Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      IImage-based class ID configuration.
   }
}
Resource, IDS_DD_IMG_JPEG_MIME_TYPES, JPEG Configuration
   string, JPEG MIME Types, , |
   HELP
      Enter a comma separated list of all the JPEG MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_BCI, BCI Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      IImage-based class ID configuration.
   }
}
Resource, IDS_DD_IMG_BCI_MIME_TYPES, BCI Configuration
   string, BCI MIME Types, , |
   HELP
      Enter a comma separated list of all the BCI MIME Types supported on the device
   }
}
Resource, IDS_AEECLSID_CAMERA, Camera Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      ICamera class ID configuration.
   }
}
Resource, IDS_AEECLSID_CAMERA2, Camera Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      ICamera class ID configuration.
   }
}
Resource, IDS_AEECLSID_CAMERA3, Camera Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      ICamera class ID configuration.
   }
}
Resource, IDS_AEECLSID_CAMERA4, Camera Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      ICamera class ID configuration.
   }
}
Resource, IDS_AEECLSID_MEDIAPCM, PCM Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_DD_AUD_PCM_MIME_TYPES, PCM Configuration
   string, PCM MIME Types, , |
   HELP
      Enter a comma separated list of all the PCM MIME Types supported on the device
   }
}
Resource, IDS_DD_AUD_PCM_RAW, PCM Configuration
   enum, PCM-raw, IDEL_LABEL_YESNO
	 HELP
	    Is the PCM-raw format supported on this device?
   }
}
Resource, IDS_AEECLSID_MEDIAXMF, XMF Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Features
      enum, Feature, IDEL_MEDIA_FEATURE
   }
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_AEECLSID_MEDIASVG, SVG Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      IMedia-based class ID configuration.
   }
}
Resource, IDS_AEECLSID_VOCODER, Vocoder Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   complex, Vocoders
   enum, Vocoder, IDEL_VOCODERS_SUPPORTED
   }    
   HELP
      IVocoder class ID configuration.
   }
}
Resource, IDS_AEECLSID_JOYSTICK, Joystick Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      IJoystick class ID configuration.
   }
}
Resource, IDS_AEECLSID_MEDIADLS, DLS Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   enum, Global,IDEL_LABEL_YESNO
   HELP
      DLS class ID configuration. If global is Yes, then DLS when loaded applies to all
      the active media and DLS linking to specific media objects is not supported.
   }
}
Resource, IDS_AEECLSID_LAST, Class ID Configuration
   enum, CLSID, IDEL_CLSID
   enum, Supported, IDEL_LABEL_YESNO
   HELP
      Do not edit this item.
   }
}
Resource, IDS_OAT_PLUG_PLAY_START, OAT Plug and Play
   uint32, OAT Plug and Play ID Start
	 HELP
      Do not edit this item.
   }
} 
Resource, IDS_OAT_PLUG_PLAY_LAST, OAT Plug and Play
   uint32, OAT Plug and Play ID Last
	 HELP
      Do not edit this item.
   }
} 
